#!/bin/bash

# set POSIX locale for numbers
LC_NUMERIC="POSIX"

./msprop_cross parameters_cross frame

# change name of timeline output file to current example
mv timeline.dat timeline_cross.dat

# Make directory for pictures
if [ -e pics ] && [ -d pics ]; then
rm pics/*
else
mkdir pics
fi

# Parameters
t_max=$(head -36 parameters_cross | tail -1)
z_max=$(head -38 parameters_cross | tail -1)
num_t_steps_data=$(head -44 parameters_cross | tail -1)
delta_t_data=$(echo "scale=2; $t_max/$num_t_steps_data" | bc)
fps=$(head -48 parameters_cross | tail -1)
z_min=$(echo "scale=2; -$z_max*0.1" | bc)


# Make and run gnuplot script for each frame
echo gnuplot...
for ((i_t=0; i_t<=$num_t_steps_data; i_t++))
do
t_value=$(printf "%.2f" $(echo "scale=2; $i_t*$delta_t_data" | bc))
sed -e "s/Z_MAX/$z_max/g;s/Z_MIN/$z_min/g;s/T_VALUE/$t_value/g" gp_template_cross.sc > gp_$i_t.sc
gnuplot gp_$i_t.sc
rm gp_$i_t.sc
done
gnuplot gp_timeline_cross.sc

# Convert eps to png alphanumerically sorted
# Gnuplot standart size: 360x252@72dpi
# density 150 => 750x525
echo convert to png...
for ((i_t=0; i_t<=$num_t_steps_data; i_t++))
do
t_value=$(printf "%.2f" $(echo "scale=2; $i_t*$delta_t_data" | bc))
f_number=$(echo "$i_t+1000000" | bc)
echo $i_t/$num_t_steps_data
convert -density 150  pics/frame_t=$t_value.eps pics/frame_$f_number.png
done

# Convert to movie
echo mencoder...
mencoder mf://pics/*.png -mf fps=$fps:type=png -vc mpng -ovc lavc -lavcopts vcodec=mpeg4:keyint=15 -o movie_cross.avi
