#!/bin/bash

# set POSIX locale for numbers
LC_NUMERIC="POSIX"

./msprop_eit parameters_eit_2 frame

# change name of timeline output file to current example
mv timeline.dat timeline_eit_2.dat

# Make directory for pictures
if [ -e pics ] && [ -d pics ]; then
rm pics/*
else
mkdir pics
fi

# Parameters
gam31=$(head -3 parameters_eit_2 | tail -1)
gam32=$(head -4 parameters_eit_2 | tail -1)
E31=$(head -10 parameters_eit_2 | tail -1)
E32=$(head -11 parameters_eit_2 | tail -1)
L=$(head -25 parameters_eit_2 | tail -1)
t_max=$(head -27 parameters_eit_2 | tail -1)
z_max=$(head -29 parameters_eit_2 | tail -1)
delta_t=$(head -31 parameters_eit_2 | tail -1)
delta_z=$(head -33 parameters_eit_2 | tail -1)
num_t_steps_data=$(head -35 parameters_eit_2 | tail -1)
delta_t_data=$(echo "scale=2; $t_max/$num_t_steps_data" | bc)
fps=$(head -39 parameters_eit_2 | tail -1)
z_min=$(echo "scale=2; -$z_max*0.1" | bc)


# Make and run gnuplot script for each frame
echo gnuplot...
for ((i_t=0; i_t<=$num_t_steps_data; i_t++))
do
t_value=$(printf "%.2f" $(echo "scale=2; $i_t*$delta_t_data" | bc))
sed -e "s/Z_MAX/$z_max/g;s/Z_MIN/$z_min/g;s/T_VALUE/$t_value/g" gp_template_eit_2.sc > gp_$i_t.sc
gnuplot gp_$i_t.sc
rm gp_$i_t.sc
done
gnuplot gp_timeline_eit_2.sc

# Convert eps to png alphanumerically sorted
# Gnuplot standart size: 360x252@72dpi
# density 150 => 750x525
echo convert to png...
for ((i_t=0; i_t<=$num_t_steps_data; i_t++))
do
t_value=$(printf "%.2f" $(echo "scale=2; $i_t*$delta_t_data" | bc))
f_number=$(echo "$i_t+1000000" | bc)
echo $i_t/$num_t_steps_data
convert -density 150  pics/frame_t=$t_value.eps pics/frame_$f_number.png
done

# Convert to movie
echo mencoder...
mencoder mf://pics/*.png -mf fps=$fps:type=png -vc mpng -ovc lavc -lavcopts vcodec=mpeg4:keyint=15 -o movie_eit_2.avi
