(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    124845,       3091]
NotebookOptionsPosition[    122240,       3009]
NotebookOutlinePosition[    123132,       3038]
CellTagsIndexPosition[    123089,       3035]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["5 level system", "Section",
 CellChangeTimes->{{3.422010023315742*^9, 3.422010027067497*^9}, {
  3.425699935440656*^9, 3.425699952751261*^9}},
 Magnification->1.25],

Cell[CellGroupData[{

Cell["EOM for the density matrix", "Subsection",
 CellChangeTimes->{{3.416289928521439*^9, 3.416289934111541*^9}, {
  3.416548180059691*^9, 3.416548187269265*^9}},
 Magnification->1.25],

Cell["\<\
Control field on 32 transition, probe field susceptibility on 34 (electric) \
and 21 (magnetic), dark state preparation on transitions 54 and 51.
For details see R. Fleischhaker and J. Evers, Phys. Rev. A 80, 063816 (2009).\
\
\>", "Text",
 CellChangeTimes->{{3.416548195176735*^9, 3.41654823017748*^9}, {
  3.422092013124676*^9, 3.422092056869834*^9}, {3.422093438923668*^9, 
  3.422093443986811*^9}, {3.422265804577858*^9, 3.422265807378067*^9}, {
  3.434694698435067*^9, 3.434694752860716*^9}, {3.475843731838764*^9, 
  3.475843757655883*^9}, {3.475843812930229*^9, 3.47584383649525*^9}},
 TextAlignment->Left,
 TextJustification->0,
 Magnification->1.25],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Code: ...\n"
}], "Subsubsection",
 Magnification->1.25],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "\"\<Global` *\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell1"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dimSystem", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[HBar]", " ", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{
      SubscriptBox["\[Omega]", 
       RowBox[{"_", ",", "_"}]], " ", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", 
       RowBox[{"_", ",", "_"}]], " ", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"t", " ", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{
      SubscriptBox["\[Gamma]", 
       RowBox[{"_", ",", "_"}]], " ", "\[Element]", " ", "Reals"}], ",", 
     RowBox[{"\[Phi]", "\[Element]", "Reals"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"l_", ",", "m_"}], "]"}], ":=", 
   RowBox[{"Array", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"KroneckerDelta", "[", 
        RowBox[{"#1", ",", "l"}], "]"}], 
       RowBox[{"KroneckerDelta", "[", 
        RowBox[{"#2", ",", "m"}], "]"}]}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"dimSystem", ",", "dimSystem"}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["H", "0"], "=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"j", "=", "1"}], "5"], 
    RowBox[{"\[HBar]", " ", 
     SubscriptBox["\[Omega]", "j"], 
     RowBox[{"A", "[", 
      RowBox[{"j", ",", "j"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Com", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"x", ".", "y"}], "-", 
    RowBox[{"y", ".", "x"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dE", "[", 
   RowBox[{"l_", ",", "m_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"\[HBar]", "/", "2"}], 
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[CapitalOmega]", 
       RowBox[{"l", ",", "m"}]], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], "*", " ", 
         SubscriptBox["\[Omega]", 
          RowBox[{"l", ",", "m"}]], "*", "t"}], "+", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["\[Phi]", 
          RowBox[{"l", ",", "m"}]]}]}]], "*", 
      RowBox[{"A", "[", 
       RowBox[{"l", ",", "m"}], "]"}]}], "+", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[CapitalOmega]", 
        RowBox[{"l", ",", "m"}]], "\[Conjugate]"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"\[ImaginaryI]", "*", " ", 
         SubscriptBox["\[Omega]", 
          RowBox[{"l", ",", "m"}]], "*", "t"}], "-", 
        RowBox[{"\[ImaginaryI]", "*", 
         SubscriptBox["\[Phi]", 
          RowBox[{"l", ",", "m"}]]}]}]], "*", 
      RowBox[{"A", "[", 
       RowBox[{"m", ",", "l"}], "]"}]}]}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["H", "I"], "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"dE", "[", 
      RowBox[{"2", ",", "1"}], "]"}]}], "-", 
    RowBox[{"dE", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "-", 
    RowBox[{"dE", "[", 
     RowBox[{"3", ",", "4"}], "]"}], "-", 
    RowBox[{"dE", "[", 
     RowBox[{"5", ",", "4"}], "]"}], "-", 
    RowBox[{"dE", "[", 
     RowBox[{"5", ",", "1"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["H", "G"], "=", 
   RowBox[{
    SubscriptBox["H", "0"], "+", 
    SubscriptBox["H", "I"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["H", "G"], "=", 
   RowBox[{
    SubscriptBox["H", "G"], "/.", 
    RowBox[{
     SubscriptBox["\[Omega]", 
      RowBox[{"l_", ",", "m_"}]], "\[Rule]", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", 
       RowBox[{"l", ",", "m"}]], "+", 
      SubscriptBox["\[Omega]", "l"], "-", 
      SubscriptBox["\[Omega]", "m"]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Hamiltonian:\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["H", "G"], "//", "MatrixForm"}], "//", "TraditionalForm"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["H", "T"], "=", 
   RowBox[{
    SubscriptBox["H", 
     RowBox[{"0", " "}]], "+", " ", 
    RowBox[{"\[HBar]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[CapitalDelta]", 
         RowBox[{"5", ",", "1"}]], 
        RowBox[{"A", "[", 
         RowBox[{"5", ",", "5"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"5", ",", "1"}]], "-", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"5", ",", "4"}]]}], ")"}], 
        RowBox[{"A", "[", 
         RowBox[{"4", ",", "4"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"3", ",", "4"}]], "+", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"5", ",", "1"}]], "-", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"5", ",", "4"}]]}], ")"}], 
        RowBox[{"A", "[", 
         RowBox[{"3", ",", "3"}], "]"}]}], "+", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", 
         RowBox[{"2", ",", "1"}]], 
        RowBox[{"A", "[", 
         RowBox[{"2", ",", "2"}], "]"}]}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Trafo-Hamiltonian:\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["H", "T"], "//", "MatrixForm"}], "//", "TraditionalForm"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["U", "1"], "=", 
   RowBox[{"MatrixExp", "[", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"\[ImaginaryI]", " ", "\[HBar]"}]], 
     SubscriptBox["H", "T"], "t"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["U", "2"], "=", 
   RowBox[{"MatrixExp", "[", 
    RowBox[{"\[ImaginaryI]", "  ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Phi]", 
         RowBox[{"5", ",", "1"}]], 
        RowBox[{"A", "[", 
         RowBox[{"5", ",", "5"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Phi]", 
           RowBox[{"5", ",", "1"}]], "-", 
          SubscriptBox["\[Phi]", 
           RowBox[{"5", ",", "4"}]]}], ")"}], 
        RowBox[{"A", "[", 
         RowBox[{"4", ",", "4"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Phi]", 
           RowBox[{"3", ",", "4"}]], "+", 
          SubscriptBox["\[Phi]", 
           RowBox[{"5", ",", "1"}]], "-", 
          SubscriptBox["\[Phi]", 
           RowBox[{"5", ",", "4"}]]}], ")"}], 
        RowBox[{"A", "[", 
         RowBox[{"3", ",", "3"}], "]"}]}], "+", 
       RowBox[{
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1"}]], 
        RowBox[{"A", "[", 
         RowBox[{"2", ",", "2"}], "]"}]}]}], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["U", "G"], "=", 
   RowBox[{
    SubscriptBox["U", "1"], ".", 
    SubscriptBox["U", "2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"V", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Inverse", "[", 
        SubscriptBox["U", "G"], "]"}], ".", 
       SubscriptBox["H", "G"], ".", 
       SubscriptBox["U", "G"]}], "-", 
      SubscriptBox["H", "T"]}], ",", "rules"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"V", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"V", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[CapitalDelta]", 
         RowBox[{"3", ",", "4"}]], "\[Rule]", 
        SubscriptBox["\[CapitalDelta]", 
         RowBox[{"2", ",", "1"}]]}], ",", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", 
         RowBox[{"5", ",", "4"}]], "\[Rule]", 
        RowBox[{
         SubscriptBox["\[CapitalDelta]", "mul"], "-", 
         SubscriptBox["\[CapitalDelta]", 
          RowBox[{"3", ",", "2"}]], "+", 
         SubscriptBox["\[CapitalDelta]", 
          RowBox[{"5", ",", "1"}]]}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"V", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"V", "/.", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", "mul"], "\[Rule]", "0"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"V", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"V", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", "4"}]], "\[Rule]", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1"}]]}], ",", 
       RowBox[{
        SubscriptBox["\[Phi]", 
         RowBox[{"5", ",", "4"}]], "\[Rule]", 
        RowBox[{
         SubscriptBox["\[Phi]", "mul"], "-", 
         SubscriptBox["\[Phi]", 
          RowBox[{"3", ",", "2"}]], "+", 
         SubscriptBox["\[Phi]", 
          RowBox[{"5", ",", "1"}]]}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Transformed Hamiltonian:\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
    RowBox[{"V", "//", "MatrixForm"}], "//", "TraditionalForm"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   OverscriptBox["\[Rho]", "^"], "=", 
   RowBox[{"Array", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Rho]", 
       RowBox[{"#1", ",", "#2"}]], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"dimSystem", ",", "dimSystem"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]34t", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Inverse", "[", 
         SubscriptBox["U", "G"], "]"}], ".", 
        OverscriptBox["\[Rho]", "^"], ".", 
        SubscriptBox["U", "G"]}], ")"}], "[", 
      RowBox[{"[", "3", "]"}], "]"}], "[", 
     RowBox[{"[", "4", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]34t", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"\[Rho]34t", "/.", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", 
       RowBox[{"3", ",", "4"}]], "\[Rule]", 
      RowBox[{
       SubscriptBox["\[Omega]", 
        RowBox[{"3", ",", "4"}]], "-", 
       SubscriptBox["\[Omega]", "3"], "+", 
       SubscriptBox["\[Omega]", "4"]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Transformation for \!\(\*SubscriptBox[\(\[Rho]\), \(3, 4\)]\): \
\!\(\*SubscriptBox[OverscriptBox[\(\[Rho]\), \(~\)], \(3, 4\)]\)=\>\"", ",", 
   "\[Rho]34t"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]21t", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Inverse", "[", 
         SubscriptBox["U", "G"], "]"}], ".", 
        OverscriptBox["\[Rho]", "^"], ".", 
        SubscriptBox["U", "G"]}], ")"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]21t", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"\[Rho]21t", "/.", 
     RowBox[{
      SubscriptBox["\[CapitalDelta]", 
       RowBox[{"2", ",", "1"}]], "\[Rule]", 
      RowBox[{
       SubscriptBox["\[Omega]", 
        RowBox[{"2", ",", "1"}]], "-", 
       SubscriptBox["\[Omega]", "2"], "+", 
       SubscriptBox["\[Omega]", "1"]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Transformation for \!\(\*SubscriptBox[\(\[Rho]\), \(2, 1\)]\): \
\!\(\*SubscriptBox[OverscriptBox[\(\[Rho]\), \(~\)], \(2, 1\)]\)=\>\"", ",", 
   "\[Rho]21t"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]32t", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Inverse", "[", 
         SubscriptBox["U", "G"], "]"}], ".", 
        OverscriptBox["\[Rho]", "^"], ".", 
        SubscriptBox["U", "G"]}], ")"}], "[", 
      RowBox[{"[", "3", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]32t", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"\[Rho]32t", "//.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[CapitalDelta]", 
         RowBox[{"3", ",", "2"}]], "\[Rule]", 
        RowBox[{
         SubscriptBox["\[Omega]", 
          RowBox[{"3", ",", "2"}]], "-", 
         SubscriptBox["\[Omega]", "3"], "+", 
         SubscriptBox["\[Omega]", "2"]}]}], ",", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", 
         RowBox[{"3", ",", "4"}]], "\[Rule]", 
        SubscriptBox["\[CapitalDelta]", 
         RowBox[{"2", ",", "1"}]]}], ",", 
       RowBox[{
        SubscriptBox["\[CapitalDelta]", 
         RowBox[{"5", ",", "4"}]], "\[Rule]", 
        RowBox[{
         SubscriptBox["\[CapitalDelta]", "mul"], "-", 
         SubscriptBox["\[CapitalDelta]", 
          RowBox[{"3", ",", "2"}]], "+", 
         SubscriptBox["\[CapitalDelta]", 
          RowBox[{"5", ",", "1"}]]}]}], ",", 
       RowBox[{
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", "4"}]], "\[Rule]", 
        SubscriptBox["\[Phi]", 
         RowBox[{"2", ",", "1"}]]}], ",", 
       RowBox[{
        SubscriptBox["\[Phi]", 
         RowBox[{"5", ",", "4"}]], "\[Rule]", 
        RowBox[{
         SubscriptBox["\[Phi]", "mul"], "-", 
         SubscriptBox["\[Phi]", 
          RowBox[{"3", ",", "2"}]], "+", 
         SubscriptBox["\[Phi]", 
          RowBox[{"5", ",", "1"}]]}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Transformation for \!\(\*SubscriptBox[\(\[Rho]\), \(3, 2\)]\): \
\!\(\*SubscriptBox[OverscriptBox[\(\[Rho]\), \(~\)], \(3, 2\)]\)=\>\"", ",", 
   "\[Rho]32t"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"uni", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"\[ImaginaryI]", " ", "\[HBar]"}]], 
      RowBox[{"Com", "[", 
       RowBox[{"V", ",", 
        OverscriptBox["\[Rho]", "^"]}], "]"}]}], ",", "rules"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"decay", "[", 
    RowBox[{"l_", ",", "m_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      SubscriptBox["\[Gamma]", 
       RowBox[{"l", ",", "m"}]], "2"]}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Com", "[", 
       RowBox[{
        RowBox[{
         OverscriptBox["\[Rho]", "^"], ".", 
         RowBox[{"A", "[", 
          RowBox[{"l", ",", "m"}], "]"}]}], ",", 
        RowBox[{"A", "[", 
         RowBox[{"m", ",", "l"}], "]"}]}], "]"}], "+", 
      RowBox[{"Com", "[", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"l", ",", "m"}], "]"}], ",", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"m", ",", "l"}], "]"}], ".", 
         OverscriptBox["\[Rho]", "^"]}]}], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rad", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"decay", "[", 
       RowBox[{"3", ",", "1"}], "]"}], "+", 
      RowBox[{"decay", "[", 
       RowBox[{"3", ",", "2"}], "]"}], "+", 
      RowBox[{"decay", "[", 
       RowBox[{"3", ",", "4"}], "]"}], "+", 
      RowBox[{"decay", "[", 
       RowBox[{"2", ",", "1"}], "]"}], "+", 
      RowBox[{"decay", "[", 
       RowBox[{"5", ",", "1"}], "]"}], "+", 
      RowBox[{"decay", "[", 
       RowBox[{"5", ",", "4"}], "]"}]}], ",", "rules"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"deph", "[", 
    RowBox[{"l_", ",", "m_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"l", ",", "m"}], "]"}], 
     SubscriptBox["\[Rho]", 
      RowBox[{"l", ",", "m"}]]}], "+", 
    RowBox[{
     RowBox[{"A", "[", 
      RowBox[{"m", ",", "l"}], "]"}], 
     SubscriptBox["\[Rho]", 
      RowBox[{"m", ",", "l"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"coll", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox["\[Gamma]", "p"]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"deph", "[", 
         RowBox[{"2", ",", "1"}], "]"}], "+", 
        RowBox[{"deph", "[", 
         RowBox[{"3", ",", "4"}], "]"}], "+", 
        RowBox[{"deph", "[", 
         RowBox[{"3", ",", "2"}], "]"}], "+", 
        RowBox[{"2", 
         RowBox[{"deph", "[", 
          RowBox[{"3", ",", "1"}], "]"}]}]}], ")"}]}], "-", 
     RowBox[{
      SubscriptBox["\[Gamma]", 
       RowBox[{"4", ",", "2"}]], 
      RowBox[{"deph", "[", 
       RowBox[{"4", ",", "2"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqns", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"uni", "+", "rad", "+", "coll"}], ",", "rules"}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqns", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eqns", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[CapitalOmega]", 
         RowBox[{"2", ",", "1"}]], "\[Rule]", 
        SubscriptBox["\[CapitalOmega]", "BP"]}], ",", 
       RowBox[{
        SubscriptBox["\[CapitalOmega]", 
         RowBox[{"3", ",", "4"}]], "\[Rule]", 
        SubscriptBox["\[CapitalOmega]", "EP"]}], ",", 
       RowBox[{
        SubscriptBox["\[CapitalOmega]", 
         RowBox[{"3", ",", "2"}]], "\[Rule]", 
        SubscriptBox["\[CapitalOmega]", "C"]}], ",", 
       RowBox[{
        SubscriptBox["\[CapitalOmega]", 
         RowBox[{"5", ",", "4"}]], "\[Rule]", 
        SubscriptBox["\[CapitalOmega]", "2"]}], ",", 
       RowBox[{
        SubscriptBox["\[CapitalOmega]", 
         RowBox[{"5", ",", "1"}]], "\[Rule]", 
        SubscriptBox["\[CapitalOmega]", "1"]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eqns", "=", 
    RowBox[{"Flatten", "[", "eqns", "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "all", " ", "population", " ", "in", " ", "dark", " ", "state", " ", 
    "superposition", " ", "of", " ", "state", " ", "1", " ", "and", " ", 
    "4"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqns", "=", 
   RowBox[{"Delete", "[", 
    RowBox[{"eqns", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "1", "}"}], ",", 
       RowBox[{"{", "4", "}"}], ",", 
       RowBox[{"{", "5", "}"}], ",", 
       RowBox[{"{", "7", "}"}], ",", 
       RowBox[{"{", "10", "}"}], ",", 
       RowBox[{"{", "13", "}"}], ",", 
       RowBox[{"{", "15", "}"}], ",", 
       RowBox[{"{", "16", "}"}], ",", 
       RowBox[{"{", "19", "}"}], ",", 
       RowBox[{"{", "20", "}"}], ",", 
       RowBox[{"{", "21", "}"}], ",", 
       RowBox[{"{", "22", "}"}], ",", 
       RowBox[{"{", "23", "}"}], ",", 
       RowBox[{"{", "24", "}"}], ",", 
       RowBox[{"{", "25", "}"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   OverscriptBox["\[Rho]", "^"], "=", 
   RowBox[{"Delete", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      OverscriptBox["\[Rho]", "^"], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "1", "}"}], ",", 
       RowBox[{"{", "4", "}"}], ",", 
       RowBox[{"{", "5", "}"}], ",", 
       RowBox[{"{", "7", "}"}], ",", 
       RowBox[{"{", "10", "}"}], ",", 
       RowBox[{"{", "13", "}"}], ",", 
       RowBox[{"{", "15", "}"}], ",", 
       RowBox[{"{", "16", "}"}], ",", 
       RowBox[{"{", "19", "}"}], ",", 
       RowBox[{"{", "20", "}"}], ",", 
       RowBox[{"{", "21", "}"}], ",", 
       RowBox[{"{", "22", "}"}], ",", 
       RowBox[{"{", "23", "}"}], ",", 
       RowBox[{"{", "24", "}"}], ",", 
       RowBox[{"{", "25", "}"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqns", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eqns", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"1", ",", "1"}]], "\[Rule]", 
        SubscriptBox["\[Rho]0", 
         RowBox[{"1", ",", "1"}]]}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"2", ",", "2"}]], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"3", ",", "3"}]], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"4", ",", "4"}]], "\[Rule]", 
        SubscriptBox["\[Rho]0", 
         RowBox[{"4", ",", "4"}]]}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"5", ",", "5"}]], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"5", ",", "1"}]], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"1", ",", "5"}]], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"5", ",", "4"}]], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"4", ",", "5"}]], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"4", ",", "1"}]], "\[Rule]", 
        SubscriptBox["\[Rho]0", 
         RowBox[{"4", ",", "1"}]]}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"1", ",", "4"}]], "\[Rule]", 
        SubscriptBox["\[Rho]0", 
         RowBox[{"4", ",", "1"}]]}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"5", ",", "2"}]], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"2", ",", "5"}]], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"5", ",", "3"}]], "\[Rule]", "0"}], ",", 
       RowBox[{
        SubscriptBox["\[Rho]", 
         RowBox[{"3", ",", "5"}]], "\[Rule]", "0"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqns", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"eqns", "/.", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Gamma]", 
        RowBox[{"3", ",", "2"}]], "\[Rule]", 
       RowBox[{
        SubscriptBox["\[Gamma]", "3"], "-", 
        SubscriptBox["\[Gamma]", 
         RowBox[{"3", ",", "1"}]], "-", 
        SubscriptBox["\[Gamma]", 
         RowBox[{"3", ",", "4"}]]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[CapitalSigma]", ",", "M"}], "}"}], "=", 
   RowBox[{"Normal", "[", 
    RowBox[{"-", 
     RowBox[{"CoefficientArrays", "[", 
      RowBox[{"eqns", ",", 
       OverscriptBox["\[Rho]", "^"]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalSigma]", "=", 
   RowBox[{"-", "\[CapitalSigma]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<M,\[CapitalSigma]:\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
    RowBox[{"M", "//", "MatrixForm"}], "//", "TraditionalForm"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
    RowBox[{"\[CapitalSigma]", "//", "MatrixForm"}], "//", 
    "TraditionalForm"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.3947959744209347`*^9, 3.394796019607855*^9}, {
   3.394796050435442*^9, 3.394796100157537*^9}, {3.394796179878022*^9, 
   3.394796240333954*^9}, {3.3947962964758368`*^9, 3.394796326498702*^9}, {
   3.394796370125268*^9, 3.394796371079192*^9}, {3.397881187429283*^9, 
   3.397881277691527*^9}, {3.397881397908836*^9, 3.397881685723113*^9}, {
   3.397881716782628*^9, 3.39788172514751*^9}, {3.397900472046429*^9, 
   3.397900511683171*^9}, {3.397900585486332*^9, 3.397900593322294*^9}, {
   3.398076437596349*^9, 3.398076483511471*^9}, {3.416548261386902*^9, 
   3.416548573551276*^9}, {3.416548642724583*^9, 3.416548754863226*^9}, {
   3.416548854886367*^9, 3.416549009004696*^9}, {3.416549047093645*^9, 
   3.416549052488327*^9}, {3.416549112815584*^9, 3.416549115833775*^9}, {
   3.416549147994573*^9, 3.416549238604943*^9}, {3.416549596109817*^9, 
   3.416549656511954*^9}, {3.416549716238039*^9, 3.416549736363206*^9}, {
   3.416549767577893*^9, 3.416549805340735*^9}, {3.416549860130493*^9, 
   3.416549926747891*^9}, {3.41655000248415*^9, 3.41655001094872*^9}, {
   3.416550097857018*^9, 3.416550111309168*^9}, {3.41655724680367*^9, 
   3.416557292801172*^9}, {3.416557490511381*^9, 3.416557506205907*^9}, {
   3.41655773385179*^9, 3.416557742518362*^9}, {3.416559265226147*^9, 
   3.416559266464175*^9}, {3.416647234311404*^9, 3.416647236859202*^9}, {
   3.416647293391703*^9, 3.416647300257344*^9}, {3.416647367215551*^9, 
   3.416647373409747*^9}, {3.422092081955633*^9, 3.42209209282063*^9}, {
   3.422092130997938*^9, 3.422092176710025*^9}, {3.422092420401489*^9, 
   3.422092584216989*^9}, {3.422092626773941*^9, 3.422092654204989*^9}, {
   3.422092940649434*^9, 3.422092973750673*^9}, 3.422093020022861*^9, {
   3.422093154582986*^9, 3.422093175932726*^9}, {3.422093216089871*^9, 
   3.422093226195519*^9}, {3.422093276506398*^9, 3.422093328864777*^9}, {
   3.422093365249041*^9, 3.422093421099283*^9}, {3.422093467847755*^9, 
   3.422093576921004*^9}, {3.422093619998141*^9, 3.422093620981225*^9}, {
   3.422093664280697*^9, 3.422093665345774*^9}, {3.422263471187633*^9, 
   3.422263495162991*^9}, {3.422263695864656*^9, 3.422263699030241*^9}, {
   3.422263803069658*^9, 3.422263922478056*^9}, {3.422264130207082*^9, 
   3.42226413708146*^9}, {3.422264173147778*^9, 3.422264200863563*^9}, {
   3.42226426514399*^9, 3.422264266120431*^9}, {3.422264422768835*^9, 
   3.422264451008478*^9}, {3.422264552234729*^9, 3.422264568348641*^9}, {
   3.422265525390002*^9, 3.422265540531472*^9}, {3.422265762261359*^9, 
   3.422265765917021*^9}, {3.422266021777035*^9, 3.422266028491106*^9}, {
   3.422335251042448*^9, 3.42233528255884*^9}, {3.422335328751771*^9, 
   3.422335337339104*^9}, {3.422336271014215*^9, 3.422336309357697*^9}, {
   3.422336353743585*^9, 3.422336374195841*^9}, 3.422336416775777*^9, {
   3.422336475495714*^9, 3.42233656369258*^9}, {3.425700079142628*^9, 
   3.425700091745507*^9}, {3.425722857211932*^9, 3.425722941648064*^9}, {
   3.42572358454542*^9, 3.425723713432891*^9}, {3.425723749905504*^9, 
   3.425723806205838*^9}, {3.425724054718325*^9, 3.425724089714694*^9}, {
   3.425724186701678*^9, 3.425724218126422*^9}, {3.425724792497022*^9, 
   3.425724807632789*^9}, {3.425724847612985*^9, 3.425724860987074*^9}, {
   3.425724925271355*^9, 3.425724938929368*^9}, {3.425725211189852*^9, 
   3.425725211955943*^9}, {3.425725271673158*^9, 3.425725306160588*^9}, {
   3.425725372371193*^9, 3.425725384998568*^9}, {3.425725418071712*^9, 
   3.425725520672659*^9}, {3.425725561238044*^9, 3.425725620118469*^9}, {
   3.425725656295994*^9, 3.425725723969903*^9}, {3.425725755294148*^9, 
   3.42572595413962*^9}, {3.425726010245629*^9, 3.425726111030271*^9}, {
   3.425788698208907*^9, 3.425788716399857*^9}, {3.425788781999406*^9, 
   3.425788890869967*^9}, {3.425789439503923*^9, 3.425789439856988*^9}, {
   3.425789486988465*^9, 3.425789530099859*^9}, {3.425789962809766*^9, 
   3.425790058828989*^9}, {3.425790099196492*^9, 3.425790134945464*^9}, {
   3.425790211780629*^9, 3.425790267162325*^9}, {3.425790638450613*^9, 
   3.425790758447868*^9}, {3.425790957325091*^9, 3.425790977358969*^9}, {
   3.425791162363104*^9, 3.425791170814491*^9}, {3.425791226992178*^9, 
   3.425791500336913*^9}, {3.425791559678414*^9, 3.425791572702976*^9}, {
   3.425791719240564*^9, 3.425791731199874*^9}, {3.425791836900851*^9, 
   3.42579188569503*^9}, {3.425791920560857*^9, 3.425791923915541*^9}, {
   3.425792065088277*^9, 3.425792168855599*^9}, {3.425792203448275*^9, 
   3.425792222533915*^9}, {3.425792490911841*^9, 3.425792531982076*^9}, 
   3.425792770666467*^9, {3.42579339802253*^9, 3.425793457147985*^9}, {
   3.425793686394887*^9, 3.425793689000809*^9}, {3.42589943415173*^9, 
   3.425899442238721*^9}, {3.42590223368945*^9, 3.425902263309098*^9}, {
   3.42596016215085*^9, 3.425960182581974*^9}, {3.425960214338012*^9, 
   3.425960237118186*^9}, {3.425964596221376*^9, 3.425964623804096*^9}, {
   3.425964943953168*^9, 3.425964969525648*^9}, {3.42596515520621*^9, 
   3.425965167368685*^9}, {3.425965339507218*^9, 3.425965414764566*^9}, {
   3.425965997724853*^9, 3.42596616154606*^9}, {3.425966255247395*^9, 
   3.425966337601612*^9}, {3.42596679071047*^9, 3.4259667939185*^9}, {
   3.434775305845975*^9, 3.434775307500599*^9}, 3.434775361789954*^9, 
   3.434776207368074*^9, {3.435469983141211*^9, 3.435469986225352*^9}, 
   3.435471375711303*^9, 3.43565605705747*^9, {3.43618361288525*^9, 
   3.436183789880452*^9}, {3.436183935870215*^9, 3.436183936220999*^9}, {
   3.436185002317573*^9, 3.436185044639862*^9}, {3.436185078629973*^9, 
   3.436185183594887*^9}, {3.4361852548128*^9, 3.436185262251364*^9}, 
   3.436186155378833*^9, 3.436186228729623*^9, {3.436186260361386*^9, 
   3.436186349694261*^9}, {3.436186404955286*^9, 3.436186429200559*^9}, {
   3.436590026456855*^9, 3.436590054948095*^9}, {3.436590128782731*^9, 
   3.436590152803722*^9}, {3.436597600850902*^9, 3.436597659635624*^9}, {
   3.436607786360591*^9, 3.436607789701919*^9}, {3.43660787821386*^9, 
   3.436607935072757*^9}, {3.43661450936386*^9, 3.436614511119941*^9}, {
   3.43782288505044*^9, 3.437822890567874*^9}, {3.437825020144369*^9, 
   3.437825022693643*^9}, {3.437827774226005*^9, 3.437827774599336*^9}, {
   3.437828192995625*^9, 3.437828194975903*^9}, {3.437828242278714*^9, 
   3.437828248905622*^9}, {3.437828692208984*^9, 3.437828698495507*^9}, {
   3.437828866172094*^9, 3.437828874574308*^9}, 3.437828930227838*^9, {
   3.43782922073209*^9, 3.437829221116679*^9}, {3.437991433019077*^9, 
   3.437991483332645*^9}, {3.43799152496036*^9, 3.437991547333168*^9}, 
   3.437991662812022*^9, 3.437993191707227*^9, {3.437993266159553*^9, 
   3.437993287061352*^9}, {3.437993353645715*^9, 3.437993356215532*^9}, {
   3.43799338715926*^9, 3.437993459449237*^9}, {3.437993531920367*^9, 
   3.437993535511549*^9}, {3.437994557744507*^9, 3.437994560054998*^9}, {
   3.437997922106242*^9, 3.437997925412326*^9}, {3.437997982242743*^9, 
   3.437997985785336*^9}, {3.438078080336595*^9, 3.438078132894681*^9}, {
   3.438078251548199*^9, 3.438078289953576*^9}, 3.438078554173507*^9, {
   3.438683765008258*^9, 3.438683822370431*^9}, {3.438683921954978*^9, 
   3.438683941271604*^9}, {3.438683974055206*^9, 3.438684075100234*^9}, {
   3.438684528077333*^9, 3.43868455714526*^9}},
 Magnification->1.25],

Cell[CellGroupData[{

Cell[BoxData["\<\"Hamiltonian:\"\>"], "Print",
 CellChangeTimes->{
  3.43782929798759*^9, 3.437991555244421*^9, 3.43799166494407*^9, 
   3.437993300510401*^9, 3.437993358698205*^9, 3.437993430783332*^9, 
   3.437993465810402*^9, 3.437993545319343*^9, 3.437994561507865*^9, 
   3.437995936056175*^9, 3.437997928400909*^9, 3.437997987714572*^9, 
   3.438078135706237*^9, 3.43807829508227*^9, 3.438078556149443*^9, 
   3.438418062730109*^9, 3.43868383084789*^9, 3.43868407664244*^9, {
   3.438684539635733*^9, 3.438684567222929*^9}, 3.442929120784805*^9, 
   3.475843854108945*^9}],

Cell[BoxData[
 TagBox[
  FormBox[
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{
         SubscriptBox["\[Omega]", "1"], " ", "\[HBar]"}], 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         TemplateBox[{RowBox[{"(", 
             SubscriptBox["\[CapitalOmega]", 
              RowBox[{"2", ",", "1"}]], ")"}]},
          "Conjugate"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[CapitalDelta]", 
               RowBox[{"2", ",", "1"}]], "-", 
              SubscriptBox["\[Omega]", "1"], "+", 
              SubscriptBox["\[Omega]", "2"]}], ")"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"2", ",", "1"}]]}]}]]}], "0", "0", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         TemplateBox[{RowBox[{"(", 
             SubscriptBox["\[CapitalOmega]", 
              RowBox[{"5", ",", "1"}]], ")"}]},
          "Conjugate"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[CapitalDelta]", 
               RowBox[{"5", ",", "1"}]], "-", 
              SubscriptBox["\[Omega]", "1"], "+", 
              SubscriptBox["\[Omega]", "5"]}], ")"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"5", ",", "1"}]]}]}]]}]},
       {
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"2", ",", "1"}]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"2", ",", "1"}]]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[CapitalDelta]", 
               RowBox[{"2", ",", "1"}]], "-", 
              SubscriptBox["\[Omega]", "1"], "+", 
              SubscriptBox["\[Omega]", "2"]}], ")"}]}]}]]}], 
        RowBox[{
         SubscriptBox["\[Omega]", "2"], " ", "\[HBar]"}], 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         TemplateBox[{RowBox[{"(", 
             SubscriptBox["\[CapitalOmega]", 
              RowBox[{"3", ",", "2"}]], ")"}]},
          "Conjugate"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[CapitalDelta]", 
               RowBox[{"3", ",", "2"}]], "-", 
              SubscriptBox["\[Omega]", "2"], "+", 
              SubscriptBox["\[Omega]", "3"]}], ")"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"3", ",", "2"}]]}]}]]}], "0", "0"},
       {"0", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"3", ",", "2"}]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"3", ",", "2"}]]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[CapitalDelta]", 
               RowBox[{"3", ",", "2"}]], "-", 
              SubscriptBox["\[Omega]", "2"], "+", 
              SubscriptBox["\[Omega]", "3"]}], ")"}]}]}]]}], 
        RowBox[{
         SubscriptBox["\[Omega]", "3"], " ", "\[HBar]"}], 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"3", ",", "4"}]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"3", ",", "4"}]]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[CapitalDelta]", 
               RowBox[{"3", ",", "4"}]], "+", 
              SubscriptBox["\[Omega]", "3"], "-", 
              SubscriptBox["\[Omega]", "4"]}], ")"}]}]}]]}], "0"},
       {"0", "0", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         TemplateBox[{RowBox[{"(", 
             SubscriptBox["\[CapitalOmega]", 
              RowBox[{"3", ",", "4"}]], ")"}]},
          "Conjugate"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[CapitalDelta]", 
               RowBox[{"3", ",", "4"}]], "+", 
              SubscriptBox["\[Omega]", "3"], "-", 
              SubscriptBox["\[Omega]", "4"]}], ")"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"3", ",", "4"}]]}]}]]}], 
        RowBox[{
         SubscriptBox["\[Omega]", "4"], " ", "\[HBar]"}], 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         TemplateBox[{RowBox[{"(", 
             SubscriptBox["\[CapitalOmega]", 
              RowBox[{"5", ",", "4"}]], ")"}]},
          "Conjugate"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[CapitalDelta]", 
               RowBox[{"5", ",", "4"}]], "-", 
              SubscriptBox["\[Omega]", "4"], "+", 
              SubscriptBox["\[Omega]", "5"]}], ")"}]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"5", ",", "4"}]]}]}]]}]},
       {
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"5", ",", "1"}]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"5", ",", "1"}]]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[CapitalDelta]", 
               RowBox[{"5", ",", "1"}]], "-", 
              SubscriptBox["\[Omega]", "1"], "+", 
              SubscriptBox["\[Omega]", "5"]}], ")"}]}]}]]}], "0", "0", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"5", ",", "4"}]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", 
             RowBox[{"5", ",", "4"}]]}], "-", 
           RowBox[{"\[ImaginaryI]", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[CapitalDelta]", 
               RowBox[{"5", ",", "4"}]], "-", 
              SubscriptBox["\[Omega]", "4"], "+", 
              SubscriptBox["\[Omega]", "5"]}], ")"}]}]}]]}], 
        RowBox[{
         SubscriptBox["\[Omega]", "5"], " ", "\[HBar]"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{
  3.43782929798759*^9, 3.437991555244421*^9, 3.43799166494407*^9, 
   3.437993300510401*^9, 3.437993358698205*^9, 3.437993430783332*^9, 
   3.437993465810402*^9, 3.437993545319343*^9, 3.437994561507865*^9, 
   3.437995936056175*^9, 3.437997928400909*^9, 3.437997987714572*^9, 
   3.438078135706237*^9, 3.43807829508227*^9, 3.438078556149443*^9, 
   3.438418062730109*^9, 3.43868383084789*^9, 3.43868407664244*^9, {
   3.438684539635733*^9, 3.438684567222929*^9}, 3.442929120784805*^9, 
   3.475843854502499*^9}],

Cell[BoxData["\<\"Trafo-Hamiltonian:\"\>"], "Print",
 CellChangeTimes->{
  3.43782929798759*^9, 3.437991555244421*^9, 3.43799166494407*^9, 
   3.437993300510401*^9, 3.437993358698205*^9, 3.437993430783332*^9, 
   3.437993465810402*^9, 3.437993545319343*^9, 3.437994561507865*^9, 
   3.437995936056175*^9, 3.437997928400909*^9, 3.437997987714572*^9, 
   3.438078135706237*^9, 3.43807829508227*^9, 3.438078556149443*^9, 
   3.438418062730109*^9, 3.43868383084789*^9, 3.43868407664244*^9, {
   3.438684539635733*^9, 3.438684567222929*^9}, 3.442929120784805*^9, 
   3.475843854950813*^9}],

Cell[BoxData[
 TagBox[
  FormBox[
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{
         SubscriptBox["\[Omega]", "1"], " ", "\[HBar]"}], "0", "0", "0", 
        "0"},
       {"0", 
        RowBox[{
         RowBox[{"\[HBar]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"2", ",", "1"}]]}], "+", 
         RowBox[{
          SubscriptBox["\[Omega]", "2"], " ", "\[HBar]"}]}], "0", "0", "0"},
       {"0", "0", 
        RowBox[{
         RowBox[{"\[HBar]", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[CapitalDelta]", 
             RowBox[{"3", ",", "4"}]], "+", 
            SubscriptBox["\[CapitalDelta]", 
             RowBox[{"5", ",", "1"}]], "-", 
            SubscriptBox["\[CapitalDelta]", 
             RowBox[{"5", ",", "4"}]]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["\[Omega]", "3"], " ", "\[HBar]"}]}], "0", "0"},
       {"0", "0", "0", 
        RowBox[{
         RowBox[{"\[HBar]", " ", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["\[CapitalDelta]", 
             RowBox[{"5", ",", "1"}]], "-", 
            SubscriptBox["\[CapitalDelta]", 
             RowBox[{"5", ",", "4"}]]}], ")"}]}], "+", 
         RowBox[{
          SubscriptBox["\[Omega]", "4"], " ", "\[HBar]"}]}], "0"},
       {"0", "0", "0", "0", 
        RowBox[{
         RowBox[{"\[HBar]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"5", ",", "1"}]]}], "+", 
         RowBox[{
          SubscriptBox["\[Omega]", "5"], " ", "\[HBar]"}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{
  3.43782929798759*^9, 3.437991555244421*^9, 3.43799166494407*^9, 
   3.437993300510401*^9, 3.437993358698205*^9, 3.437993430783332*^9, 
   3.437993465810402*^9, 3.437993545319343*^9, 3.437994561507865*^9, 
   3.437995936056175*^9, 3.437997928400909*^9, 3.437997987714572*^9, 
   3.438078135706237*^9, 3.43807829508227*^9, 3.438078556149443*^9, 
   3.438418062730109*^9, 3.43868383084789*^9, 3.43868407664244*^9, {
   3.438684539635733*^9, 3.438684567222929*^9}, 3.442929120784805*^9, 
   3.475843855959479*^9}],

Cell[BoxData["\<\"Transformed Hamiltonian:\"\>"], "Print",
 CellChangeTimes->{
  3.43782929798759*^9, 3.437991555244421*^9, 3.43799166494407*^9, 
   3.437993300510401*^9, 3.437993358698205*^9, 3.437993430783332*^9, 
   3.437993465810402*^9, 3.437993545319343*^9, 3.437994561507865*^9, 
   3.437995936056175*^9, 3.437997928400909*^9, 3.437997987714572*^9, 
   3.438078135706237*^9, 3.43807829508227*^9, 3.438078556149443*^9, 
   3.438418062730109*^9, 3.43868383084789*^9, 3.43868407664244*^9, {
   3.438684539635733*^9, 3.438684567222929*^9}, 3.442929120784805*^9, 
   3.475843856392149*^9}],

Cell[BoxData[
 TagBox[
  FormBox[
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[HBar]", " ", 
           TemplateBox[{RowBox[{"(", 
               SubscriptBox["\[CapitalOmega]", 
                RowBox[{"2", ",", "1"}]], ")"}]},
            "Conjugate"]}], "2"]}], "0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[HBar]", " ", 
           TemplateBox[{RowBox[{"(", 
               SubscriptBox["\[CapitalOmega]", 
                RowBox[{"5", ",", "1"}]], ")"}]},
            "Conjugate"]}], "2"]}]},
       {
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"2", ",", "1"}]]}], 
        RowBox[{
         RowBox[{"-", "\[HBar]"}], " ", 
         SubscriptBox["\[CapitalDelta]", 
          RowBox[{"2", ",", "1"}]]}], 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SubscriptBox["\[Phi]", "mul"]}]], " ", 
         TemplateBox[{RowBox[{"(", 
             SubscriptBox["\[CapitalOmega]", 
              RowBox[{"3", ",", "2"}]], ")"}]},
          "Conjugate"]}], "0", "0"},
       {"0", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"3", ",", "2"}]], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "mul"]}]]}], 
        RowBox[{
         RowBox[{"-", "\[HBar]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["\[CapitalDelta]", 
            RowBox[{"2", ",", "1"}]], "+", 
           SubscriptBox["\[CapitalDelta]", 
            RowBox[{"3", ",", "2"}]]}], ")"}]}], 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"3", ",", "4"}]]}], "0"},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[HBar]", " ", 
           TemplateBox[{RowBox[{"(", 
               SubscriptBox["\[CapitalOmega]", 
                RowBox[{"3", ",", "4"}]], ")"}]},
            "Conjugate"]}], "2"]}], 
        RowBox[{
         RowBox[{"-", "\[HBar]"}], " ", 
         SubscriptBox["\[CapitalDelta]", 
          RowBox[{"3", ",", "2"}]]}], 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[HBar]", " ", 
           TemplateBox[{RowBox[{"(", 
               SubscriptBox["\[CapitalOmega]", 
                RowBox[{"5", ",", "4"}]], ")"}]},
            "Conjugate"]}], "2"]}]},
       {
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"5", ",", "1"}]]}], "0", "0", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[HBar]", " ", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"5", ",", "4"}]]}], 
        RowBox[{
         RowBox[{"-", "\[HBar]"}], " ", 
         SubscriptBox["\[CapitalDelta]", 
          RowBox[{"5", ",", "1"}]]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{
  3.43782929798759*^9, 3.437991555244421*^9, 3.43799166494407*^9, 
   3.437993300510401*^9, 3.437993358698205*^9, 3.437993430783332*^9, 
   3.437993465810402*^9, 3.437993545319343*^9, 3.437994561507865*^9, 
   3.437995936056175*^9, 3.437997928400909*^9, 3.437997987714572*^9, 
   3.438078135706237*^9, 3.43807829508227*^9, 3.438078556149443*^9, 
   3.438418062730109*^9, 3.43868383084789*^9, 3.43868407664244*^9, {
   3.438684539635733*^9, 3.438684567222929*^9}, 3.442929120784805*^9, 
   3.475843856662547*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Transformation for \\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(3, 4\
\\)]\\): \\!\\(\\*SubscriptBox[OverscriptBox[\\(\[Rho]\\), \\(~\\)], \\(3, \
4\\)]\\)=\"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Phi]", 
          RowBox[{"3", ",", "4"}]]}], "+", 
        RowBox[{"t", " ", 
         SubscriptBox["\[Omega]", 
          RowBox[{"3", ",", "4"}]]}]}], ")"}]}]], " ", 
    SubscriptBox["\[Rho]", 
     RowBox[{"3", ",", "4"}]]}]}],
  SequenceForm[
  "Transformation for \!\(\*SubscriptBox[\(\[Rho]\), \(3, 4\)]\): \
\!\(\*SubscriptBox[OverscriptBox[\(\[Rho]\), \(~\)], \(3, 4\)]\)=", 
   E^(Complex[
      0, 1] (-Subscript[$CellContext`\[Phi], 3, 4] + $CellContext`t 
       Subscript[$CellContext`\[Omega], 3, 4])) 
   Subscript[$CellContext`\[Rho], 3, 4]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.43782929798759*^9, 3.437991555244421*^9, 3.43799166494407*^9, 
   3.437993300510401*^9, 3.437993358698205*^9, 3.437993430783332*^9, 
   3.437993465810402*^9, 3.437993545319343*^9, 3.437994561507865*^9, 
   3.437995936056175*^9, 3.437997928400909*^9, 3.437997987714572*^9, 
   3.438078135706237*^9, 3.43807829508227*^9, 3.438078556149443*^9, 
   3.438418062730109*^9, 3.43868383084789*^9, 3.43868407664244*^9, {
   3.438684539635733*^9, 3.438684567222929*^9}, 3.442929120784805*^9, 
   3.475843856796224*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Transformation for \\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(2, 1\
\\)]\\): \\!\\(\\*SubscriptBox[OverscriptBox[\\(\[Rho]\\), \\(~\\)], \\(2, \
1\\)]\\)=\"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SubscriptBox["\[Phi]", 
          RowBox[{"2", ",", "1"}]]}], "+", 
        RowBox[{"t", " ", 
         SubscriptBox["\[Omega]", 
          RowBox[{"2", ",", "1"}]]}]}], ")"}]}]], " ", 
    SubscriptBox["\[Rho]", 
     RowBox[{"2", ",", "1"}]]}]}],
  SequenceForm[
  "Transformation for \!\(\*SubscriptBox[\(\[Rho]\), \(2, 1\)]\): \
\!\(\*SubscriptBox[OverscriptBox[\(\[Rho]\), \(~\)], \(2, 1\)]\)=", 
   E^(Complex[
      0, 1] (-Subscript[$CellContext`\[Phi], 2, 1] + $CellContext`t 
       Subscript[$CellContext`\[Omega], 2, 1])) 
   Subscript[$CellContext`\[Rho], 2, 1]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.43782929798759*^9, 3.437991555244421*^9, 3.43799166494407*^9, 
   3.437993300510401*^9, 3.437993358698205*^9, 3.437993430783332*^9, 
   3.437993465810402*^9, 3.437993545319343*^9, 3.437994561507865*^9, 
   3.437995936056175*^9, 3.437997928400909*^9, 3.437997987714572*^9, 
   3.438078135706237*^9, 3.43807829508227*^9, 3.438078556149443*^9, 
   3.438418062730109*^9, 3.43868383084789*^9, 3.43868407664244*^9, {
   3.438684539635733*^9, 3.438684567222929*^9}, 3.442929120784805*^9, 
   3.475843857081789*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Transformation for \\!\\(\\*SubscriptBox[\\(\[Rho]\\), \\(3, 2\
\\)]\\): \\!\\(\\*SubscriptBox[OverscriptBox[\\(\[Rho]\\), \\(~\\)], \\(3, \
2\\)]\\)=\"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "t"}], " ", 
         SubscriptBox["\[CapitalDelta]", "mul"]}], "+", 
        SubscriptBox["\[Phi]", "mul"], "-", 
        SubscriptBox["\[Phi]", 
         RowBox[{"3", ",", "2"}]], "+", 
        RowBox[{"t", " ", 
         SubscriptBox["\[Omega]", 
          RowBox[{"3", ",", "2"}]]}]}], ")"}]}]], " ", 
    SubscriptBox["\[Rho]", 
     RowBox[{"3", ",", "2"}]]}]}],
  SequenceForm[
  "Transformation for \!\(\*SubscriptBox[\(\[Rho]\), \(3, 2\)]\): \
\!\(\*SubscriptBox[OverscriptBox[\(\[Rho]\), \(~\)], \(3, 2\)]\)=", 
   E^(Complex[
      0, 1] (-$CellContext`t 
       Subscript[$CellContext`\[CapitalDelta], $CellContext`mul] + 
      Subscript[$CellContext`\[Phi], $CellContext`mul] - 
      Subscript[$CellContext`\[Phi], 3, 2] + $CellContext`t 
       Subscript[$CellContext`\[Omega], 3, 2])) 
   Subscript[$CellContext`\[Rho], 3, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.43782929798759*^9, 3.437991555244421*^9, 3.43799166494407*^9, 
   3.437993300510401*^9, 3.437993358698205*^9, 3.437993430783332*^9, 
   3.437993465810402*^9, 3.437993545319343*^9, 3.437994561507865*^9, 
   3.437995936056175*^9, 3.437997928400909*^9, 3.437997987714572*^9, 
   3.438078135706237*^9, 3.43807829508227*^9, 3.438078556149443*^9, 
   3.438418062730109*^9, 3.43868383084789*^9, 3.43868407664244*^9, {
   3.438684539635733*^9, 3.438684567222929*^9}, 3.442929120784805*^9, 
   3.475843857374187*^9}],

Cell[BoxData["\<\"M,\[CapitalSigma]:\"\>"], "Print",
 CellChangeTimes->{
  3.43782929798759*^9, 3.437991555244421*^9, 3.43799166494407*^9, 
   3.437993300510401*^9, 3.437993358698205*^9, 3.437993430783332*^9, 
   3.437993465810402*^9, 3.437993545319343*^9, 3.437994561507865*^9, 
   3.437995936056175*^9, 3.437997928400909*^9, 3.437997987714572*^9, 
   3.438078135706237*^9, 3.43807829508227*^9, 3.438078556149443*^9, 
   3.438418062730109*^9, 3.43868383084789*^9, 3.43868407664244*^9, {
   3.438684539635733*^9, 3.438684567222929*^9}, 3.442929120784805*^9, 
   3.475843864923347*^9}],

Cell[BoxData[
 TagBox[
  FormBox[
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{
         FractionBox[
          SubscriptBox["\[Gamma]", 
           RowBox[{"2", ",", "1"}]], "2"], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"2", ",", "1"}]]}], "+", 
         SubscriptBox["\[Gamma]", "p"]}], 
        RowBox[{
         FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
         SubscriptBox["\[CapitalOmega]", "C"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "mul"]}]]}], "0", "0", "0", "0", "0", "0", 
        "0", "0"},
       {
        RowBox[{
         FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SubscriptBox["\[Phi]", "mul"]}]], " ", 
         TemplateBox[{RowBox[{"(", 
             SubscriptBox["\[CapitalOmega]", "C"], ")"}]},
          "Conjugate"]}], 
        RowBox[{
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"2", ",", "1"}]]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"3", ",", "2"}]]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Gamma]", "p"]}], "+", 
         FractionBox[
          SubscriptBox["\[Gamma]", "3"], "2"]}], "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           TemplateBox[{RowBox[{"(", 
               SubscriptBox["\[CapitalOmega]", "BP"], ")"}]},
            "Conjugate"]}], "2"]}], "0", "0", "0", "0", "0", "0"},
       {"0", "0", 
        RowBox[{
         FractionBox[
          SubscriptBox["\[Gamma]", 
           RowBox[{"2", ",", "1"}]], "2"], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"2", ",", "1"}]]}], "+", 
         SubscriptBox["\[Gamma]", "p"]}], "0", "0", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SubscriptBox["\[Phi]", "mul"]}]], " ", 
         TemplateBox[{RowBox[{"(", 
             SubscriptBox["\[CapitalOmega]", "C"], ")"}]},
          "Conjugate"]}], "0", "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[CapitalOmega]", "BP"]}], "2"]}], "0", 
        RowBox[{
         FractionBox[
          SubscriptBox["\[Gamma]", 
           RowBox[{"2", ",", "1"}]], "2"], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"3", ",", "2"}]]}], "+", 
         SubscriptBox["\[Gamma]", "p"], "+", 
         FractionBox[
          SubscriptBox["\[Gamma]", "3"], "2"]}], 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          TemplateBox[{RowBox[{"(", 
              SubscriptBox["\[CapitalOmega]", "EP"], ")"}]},
           "Conjugate"]}], "2"], "0", "0", "0", "0", "0"},
       {"0", "0", "0", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalOmega]", "EP"]}], "2"], 
        RowBox[{
         FractionBox[
          SubscriptBox["\[Gamma]", 
           RowBox[{"2", ",", "1"}]], "2"], "+", 
         SubscriptBox["\[Gamma]", 
          RowBox[{"4", ",", "2"}]], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"2", ",", "1"}]]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"3", ",", "2"}]]}]}], "0", "0", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SubscriptBox["\[Phi]", "mul"]}]], " ", 
         TemplateBox[{RowBox[{"(", 
             SubscriptBox["\[CapitalOmega]", "C"], ")"}]},
          "Conjugate"]}], "0", "0"},
       {"0", "0", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
         SubscriptBox["\[CapitalOmega]", "C"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "mul"]}]]}], "0", "0", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[CapitalDelta]", 
            RowBox[{"2", ",", "1"}]]}]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"3", ",", "2"}]]}], "+", 
         RowBox[{"2", " ", 
          SubscriptBox["\[Gamma]", "p"]}], "+", 
         FractionBox[
          SubscriptBox["\[Gamma]", "3"], "2"]}], 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalOmega]", "BP"]}], "2"], "0", "0", "0"},
       {"0", "0", "0", "0", "0", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          TemplateBox[{RowBox[{"(", 
              SubscriptBox["\[CapitalOmega]", "BP"], ")"}]},
           "Conjugate"]}], "2"], 
        RowBox[{
         FractionBox[
          SubscriptBox["\[Gamma]", 
           RowBox[{"2", ",", "1"}]], "2"], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"3", ",", "2"}]]}], "+", 
         SubscriptBox["\[Gamma]", "p"], "+", 
         FractionBox[
          SubscriptBox["\[Gamma]", "3"], "2"]}], "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[CapitalOmega]", "EP"]}], "2"]}], "0"},
       {"0", "0", "0", "0", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
         SubscriptBox["\[CapitalOmega]", "C"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "mul"]}]]}], "0", "0", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SubscriptBox["\[CapitalDelta]", 
             RowBox[{"2", ",", "1"}]]}], "+", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Gamma]", "p"]}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Gamma]", "3"]}]}], ")"}]}], "0", "0"},
       {"0", "0", "0", "0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[ImaginaryI]", " ", 
           TemplateBox[{RowBox[{"(", 
               SubscriptBox["\[CapitalOmega]", "EP"], ")"}]},
            "Conjugate"]}], "2"]}], "0", 
        RowBox[{
         FractionBox[
          SubscriptBox["\[Gamma]", 
           RowBox[{"2", ",", "1"}]], "2"], "+", 
         SubscriptBox["\[Gamma]", 
          RowBox[{"4", ",", "2"}]], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"2", ",", "1"}]]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"3", ",", "2"}]]}]}], 
        RowBox[{
         FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
         SubscriptBox["\[CapitalOmega]", "C"], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[Phi]", "mul"]}]]}]},
       {"0", "0", "0", "0", "0", "0", "0", "0", 
        RowBox[{
         FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SubscriptBox["\[Phi]", "mul"]}]], " ", 
         TemplateBox[{RowBox[{"(", 
             SubscriptBox["\[CapitalOmega]", "C"], ")"}]},
          "Conjugate"]}], 
        RowBox[{
         RowBox[{"\[ImaginaryI]", " ", 
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"2", ",", "1"}]]}], "+", 
         SubscriptBox["\[Gamma]", "p"], "+", 
         FractionBox[
          SubscriptBox["\[Gamma]", "3"], "2"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{
  3.43782929798759*^9, 3.437991555244421*^9, 3.43799166494407*^9, 
   3.437993300510401*^9, 3.437993358698205*^9, 3.437993430783332*^9, 
   3.437993465810402*^9, 3.437993545319343*^9, 3.437994561507865*^9, 
   3.437995936056175*^9, 3.437997928400909*^9, 3.437997987714572*^9, 
   3.438078135706237*^9, 3.43807829508227*^9, 3.438078556149443*^9, 
   3.438418062730109*^9, 3.43868383084789*^9, 3.43868407664244*^9, {
   3.438684539635733*^9, 3.438684567222929*^9}, 3.442929120784805*^9, 
   3.475843865183281*^9}],

Cell[BoxData[
 TagBox[
  FormBox[
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["\[Rho]0", 
           RowBox[{"1", ",", "1"}]], " ", 
          TemplateBox[{RowBox[{"(", 
              SubscriptBox["\[CapitalOmega]", "BP"], ")"}]},
           "Conjugate"]}]},
        {
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["\[Rho]0", 
           RowBox[{"4", ",", "1"}]], " ", 
          TemplateBox[{RowBox[{"(", 
              SubscriptBox["\[CapitalOmega]", "EP"], ")"}]},
           "Conjugate"]}]},
        {
         RowBox[{
          FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["\[Rho]0", 
           RowBox[{"1", ",", "1"}]], " ", 
          SubscriptBox["\[CapitalOmega]", "BP"]}]},
        {"0"},
        {
         RowBox[{
          FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["\[Rho]0", 
           RowBox[{"4", ",", "1"}]], " ", 
          SubscriptBox["\[CapitalOmega]", "BP"]}]},
        {
         RowBox[{
          FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["\[Rho]0", 
           RowBox[{"4", ",", "1"}]], " ", 
          SubscriptBox["\[CapitalOmega]", "EP"]}]},
        {"0"},
        {
         RowBox[{
          FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["\[Rho]0", 
           RowBox[{"4", ",", "4"}]], " ", 
          SubscriptBox["\[CapitalOmega]", "EP"]}]},
        {
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["\[Rho]0", 
           RowBox[{"4", ",", "1"}]], " ", 
          TemplateBox[{RowBox[{"(", 
              SubscriptBox["\[CapitalOmega]", "BP"], ")"}]},
           "Conjugate"]}]},
        {
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
          SubscriptBox["\[Rho]0", 
           RowBox[{"4", ",", "4"}]], " ", 
          TemplateBox[{RowBox[{"(", 
              SubscriptBox["\[CapitalOmega]", "EP"], ")"}]},
           "Conjugate"]}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{
  3.43782929798759*^9, 3.437991555244421*^9, 3.43799166494407*^9, 
   3.437993300510401*^9, 3.437993358698205*^9, 3.437993430783332*^9, 
   3.437993465810402*^9, 3.437993545319343*^9, 3.437994561507865*^9, 
   3.437995936056175*^9, 3.437997928400909*^9, 3.437997987714572*^9, 
   3.438078135706237*^9, 3.43807829508227*^9, 3.438078556149443*^9, 
   3.438418062730109*^9, 3.43868383084789*^9, 3.43868407664244*^9, {
   3.438684539635733*^9, 3.438684567222929*^9}, 3.442929120784805*^9, 
   3.475843865443568*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Convert EOM into C-Code and write to file", "Subsection",
 CellChangeTimes->{{3.404470720427341*^9, 3.404470721359674*^9}, {
   3.404470790201727*^9, 3.404470819770951*^9}, {3.404471132999029*^9, 
   3.404471147944249*^9}, {3.404471517428168*^9, 3.404471547261367*^9}, {
   3.40447159581952*^9, 3.404471672444252*^9}, {3.404471713469586*^9, 
   3.404471860029159*^9}, {3.404471893965864*^9, 3.40447197795007*^9}, {
   3.404472017512518*^9, 3.404472048570308*^9}, {3.404472099906455*^9, 
   3.404472387212804*^9}, {3.404472417784266*^9, 3.404472470579501*^9}, {
   3.404472556528642*^9, 3.404472569648758*^9}, {3.404474741117033*^9, 
   3.404474794492275*^9}, {3.404475043454*^9, 3.404475067553086*^9}, {
   3.404475207390439*^9, 3.404475210906078*^9}, 3.404475276250468*^9, {
   3.404475320160246*^9, 3.404475337935348*^9}, {3.404475399735286*^9, 
   3.404475434888152*^9}, 3.404475629366098*^9, {3.404475978261277*^9, 
   3.404476032084755*^9}, 3.404476066205592*^9, {3.40447615531176*^9, 
   3.404476156571499*^9}, {3.404476225315834*^9, 3.404476253395292*^9}, {
   3.404476692722001*^9, 3.404476747630695*^9}, {3.404476800960553*^9, 
   3.404476816365576*^9}, {3.404476854668126*^9, 3.404476861264874*^9}, {
   3.404476946410359*^9, 3.404476946817547*^9}, {3.404477023005928*^9, 
   3.404477058135398*^9}, {3.404477126271064*^9, 3.404477126712451*^9}, {
   3.404477310086568*^9, 3.404477324109813*^9}, {3.404477451201698*^9, 
   3.404477550390558*^9}, {3.404477580524181*^9, 3.404477603807426*^9}, {
   3.404478041086893*^9, 3.404478042289953*^9}, {3.404478107465902*^9, 
   3.404478111001769*^9}, 3.404478286249575*^9, {3.404478339258664*^9, 
   3.404478439341352*^9}, {3.404478536053118*^9, 3.404478659428097*^9}, {
   3.40447869931457*^9, 3.404478808966521*^9}, {3.404478858009904*^9, 
   3.404478916684908*^9}, {3.404555770181277*^9, 3.404555792910592*^9}, {
   3.404555826005772*^9, 3.404555868579495*^9}, {3.404555926466546*^9, 
   3.404555937479506*^9}, {3.404556009176215*^9, 3.404556058565699*^9}, {
   3.404556116257374*^9, 3.40455613408253*^9}, {3.404556249720549*^9, 
   3.40455626861116*^9}, {3.40455634784389*^9, 3.404556372578023*^9}, {
   3.404556909136681*^9, 3.40455695117469*^9}, {3.404557005503864*^9, 
   3.404557029222947*^9}, {3.404557111107647*^9, 3.404557208729087*^9}, {
   3.404557328396328*^9, 3.404557337692525*^9}, {3.404557500292429*^9, 
   3.404557585211991*^9}, {3.404557619690573*^9, 3.404557625645853*^9}, {
   3.404557664915916*^9, 3.404557700732037*^9}, {3.404557800565458*^9, 
   3.404557802410394*^9}, {3.404557836292713*^9, 3.404557859875299*^9}, {
   3.404557911071419*^9, 3.404557915788647*^9}, {3.404558262590172*^9, 
   3.40455834310637*^9}, {3.404561291523026*^9, 3.404561457693624*^9}, 
   3.404561871036479*^9, 3.404561940175434*^9, {3.404562059086969*^9, 
   3.404562062391779*^9}, {3.40456385125818*^9, 3.404563889761395*^9}, {
   3.404563926958605*^9, 3.404563969826161*^9}, {3.404564488105459*^9, 
   3.404564509612625*^9}, {3.404564572860146*^9, 3.404564803988728*^9}, {
   3.404564962225087*^9, 3.404564965357859*^9}, {3.404565002225835*^9, 
   3.404565086573603*^9}, {3.40456513902873*^9, 3.404565151402328*^9}, {
   3.404565235341117*^9, 3.404565351550748*^9}, {3.404565395900853*^9, 
   3.404565398356122*^9}, {3.404565461871571*^9, 3.404565477483662*^9}, {
   3.404637130402836*^9, 3.404637146574069*^9}, {3.404637202971023*^9, 
   3.404637236131497*^9}, {3.404637281776718*^9, 3.404637439385585*^9}, {
   3.404637512280809*^9, 3.404637513249907*^9}, {3.404637619687091*^9, 
   3.404637620740917*^9}, {3.404637698680536*^9, 3.404637787405621*^9}, {
   3.404637973177366*^9, 3.404637984023086*^9}, {3.404638169568919*^9, 
   3.404638182297179*^9}, {3.404638233787457*^9, 3.404638246892325*^9}, {
   3.404638543829268*^9, 3.404638548804682*^9}, {3.404638587676433*^9, 
   3.404638591035332*^9}, {3.404638795954265*^9, 3.404638798665974*^9}, {
   3.404638875893642*^9, 3.404638876458881*^9}, {3.404638954292542*^9, 
   3.404638959219343*^9}, {3.404639018282496*^9, 3.404639018507842*^9}, {
   3.404639053534464*^9, 3.404639060113258*^9}, {3.404639146289313*^9, 
   3.404639154344866*^9}, {3.404639232757717*^9, 3.404639249492263*^9}, {
   3.404640590067939*^9, 3.404640615333812*^9}, {3.404640675363501*^9, 
   3.404640682028829*^9}, {3.404640718188082*^9, 3.404640733623324*^9}, {
   3.404640847160872*^9, 3.404640891088787*^9}, {3.404641455447882*^9, 
   3.404641499269695*^9}, {3.404641539105562*^9, 3.40464161404703*^9}, {
   3.40464183374608*^9, 3.404641834805097*^9}, {3.404641885796851*^9, 
   3.404641928450511*^9}, {3.40464312487666*^9, 3.404643137916263*^9}, {
   3.404643504480214*^9, 3.404643516517594*^9}, {3.404643555102277*^9, 
   3.404643653734854*^9}, {3.404643784089685*^9, 3.404643806739114*^9}, {
   3.404644476074528*^9, 3.404644566201548*^9}, {3.404644713207228*^9, 
   3.404644715665452*^9}, {3.404644827756595*^9, 3.404644888809208*^9}, {
   3.404644976023538*^9, 3.40464498567272*^9}, {3.404650777092396*^9, 
   3.404650791743922*^9}, {3.404650970412115*^9, 3.404651004414445*^9}, {
   3.404651047408983*^9, 3.404651056453298*^9}, {3.404651145572649*^9, 
   3.404651155075835*^9}, {3.404651312627621*^9, 3.404651313853926*^9}, {
   3.405339003308071*^9, 3.405339007327045*^9}, {3.423557696511923*^9, 
   3.423557708056352*^9}, {3.423558486842195*^9, 3.42355849247938*^9}, {
   3.423558620942606*^9, 3.423558621376742*^9}, 3.423562823050889*^9, {
   3.423562876969494*^9, 3.423562887301527*^9}, {3.423563051060893*^9, 
   3.423563075330247*^9}, {3.42356310897701*^9, 3.423563145783145*^9}, {
   3.423563191476733*^9, 3.42356319202269*^9}, {3.423563663130091*^9, 
   3.423563680516834*^9}, {3.42356383682297*^9, 3.423563837314065*^9}, 
   3.43782178004509*^9, {3.437821820824486*^9, 3.437821847501806*^9}, {
   3.437822402852235*^9, 3.437822422510657*^9}, {3.43782272495823*^9, 
   3.43782273412898*^9}, {3.437825177602733*^9, 3.437825190512507*^9}, {
   3.437825274782524*^9, 3.43782527721959*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"redeqns", "=", 
     RowBox[{"Delete", "[", 
      RowBox[{"eqns", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "1", "}"}], ",", 
         RowBox[{"{", "2", "}"}], ",", 
         RowBox[{"{", "4", "}"}], ",", 
         RowBox[{"{", "5", "}"}], ",", 
         RowBox[{"{", "10", "}"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"redeqns", "=", 
     RowBox[{"Expand", "[", "redeqns", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"path", "=", "\"\<\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eom", "=", "redeqns"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eom", "=", 
     RowBox[{"eom", "/.", 
      RowBox[{"{", " ", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Rho]", 
          RowBox[{"2", ",", "4"}]], "\[Rule]", 
         RowBox[{
          SubscriptBox["\[Rho]", 
           RowBox[{"4", ",", "2"}]], "\[Conjugate]"}]}], ",", 
        RowBox[{
         SubscriptBox["\[Rho]", 
          RowBox[{"4", ",", "3"}]], "\[Rule]", 
         RowBox[{
          SubscriptBox["\[Rho]", 
           RowBox[{"3", ",", "4"}]], "\[Conjugate]"}]}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eom", "=", 
     RowBox[{"eom", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["\[Rho]0", 
          RowBox[{"1", ",", "1"}]], "\[Rule]", "rho011"}], ",", 
        RowBox[{
         SubscriptBox["\[Rho]0", 
          RowBox[{"4", ",", "4"}]], "\[Rule]", "rho044"}], ",", 
        RowBox[{
         SubscriptBox["\[Rho]0", 
          RowBox[{"4", ",", "1"}]], "\[Rule]", "rho041"}], ",", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            SubscriptBox["\[Phi]", "mul"]}]], " ", 
          SubscriptBox["\[CapitalOmega]", "C"]}], "\[Rule]", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"3", ",", "2"}]]}], ",", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", 
            SubscriptBox["\[Phi]", "mul"]}]], " ", 
          RowBox[{
           SubscriptBox["\[CapitalOmega]", "C"], "\[Conjugate]"}]}], 
         "\[Rule]", 
         RowBox[{
          SubscriptBox["\[CapitalOmega]", 
           RowBox[{"3", ",", "2"}]], "\[Conjugate]"}]}], ",", 
        RowBox[{
         SubscriptBox["\[Gamma]", "p"], "\[Rule]", 
         SubscriptBox["\[Gamma]", 
          RowBox[{"c", ",", "ol"}]]}], ",", 
        RowBox[{
         SubscriptBox["\[Gamma]", "3"], "\[Rule]", 
         SubscriptBox["\[Gamma]", 
          RowBox[{"3", ",", "all"}]]}], ",", 
        RowBox[{
         SubscriptBox["\[CapitalOmega]", "EP"], "\[Rule]", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"3", ",", "4"}]]}], ",", 
        RowBox[{
         SubscriptBox["\[CapitalOmega]", "BP"], "\[Rule]", 
         SubscriptBox["\[CapitalOmega]", 
          RowBox[{"2", ",", "1"}]]}]}], "}"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eom", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"eom", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[CapitalDelta]", 
           RowBox[{"3", ",", "2"}]], "\[Rule]", "0"}], ",", 
         RowBox[{
          SubscriptBox["\[Phi]", "mul"], "\[Rule]", "0"}]}], "}"}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eom", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{"eom", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[CapitalOmega]", 
           RowBox[{"3", ",", "2"}]], "\[Rule]", 
          RowBox[{
           SubscriptBox["\[CapitalOmega]", 
            RowBox[{"3", ",", "2"}]], "+", 
           RowBox[{"L", " ", 
            SubscriptBox["\[Gamma]", 
             RowBox[{"3", ",", "4"}]], 
            SubscriptBox["\[Rho]", 
             RowBox[{"3", ",", "2"}]]}]}]}], ",", 
         RowBox[{
          SubscriptBox["\[CapitalOmega]", 
           RowBox[{"3", ",", "4"}]], "\[Rule]", 
          RowBox[{
           SubscriptBox["\[CapitalOmega]", 
            RowBox[{"3", ",", "4"}]], "+", 
           RowBox[{"L", " ", 
            SubscriptBox["\[Gamma]", 
             RowBox[{"3", ",", "4"}]], 
            SubscriptBox["\[Rho]", 
             RowBox[{"3", ",", "4"}]]}]}]}], ",", 
         RowBox[{
          SubscriptBox["\[CapitalOmega]", 
           RowBox[{"2", ",", "1"}]], "\[Rule]", 
          RowBox[{
           SubscriptBox["\[CapitalOmega]", 
            RowBox[{"2", ",", "1"}]], "+", 
           RowBox[{"L", " ", "alpha", " ", "alpha", " ", 
            SubscriptBox["\[Gamma]", 
             RowBox[{"3", ",", "4"}]], 
            SubscriptBox["\[Rho]", 
             RowBox[{"2", ",", "1"}]]}]}]}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<EOM:\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"redeqns", "//", "MatrixForm"}], "//", "TraditionalForm"}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"eom", "//", "MatrixForm"}], "//", "TraditionalForm"}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.3947959744209347`*^9, 3.394796019607855*^9}, {
   3.394796050435442*^9, 3.394796100157537*^9}, {3.394796179878022*^9, 
   3.394796240333954*^9}, {3.3947962964758368`*^9, 3.394796326498702*^9}, {
   3.394796370125268*^9, 3.394796371079192*^9}, {3.397881187429283*^9, 
   3.397881277691527*^9}, {3.397881397908836*^9, 3.397881685723113*^9}, {
   3.397881716782628*^9, 3.39788172514751*^9}, {3.397900472046429*^9, 
   3.397900511683171*^9}, {3.397900585486332*^9, 3.397900593322294*^9}, {
   3.398076437596349*^9, 3.398076483511471*^9}, {3.416548261386902*^9, 
   3.416548573551276*^9}, {3.416548642724583*^9, 3.416548754863226*^9}, {
   3.416548854886367*^9, 3.416549009004696*^9}, {3.416549047093645*^9, 
   3.416549052488327*^9}, {3.416549112815584*^9, 3.416549115833775*^9}, {
   3.416549147994573*^9, 3.416549238604943*^9}, {3.416549596109817*^9, 
   3.416549656511954*^9}, {3.416549716238039*^9, 3.416549736363206*^9}, {
   3.416549767577893*^9, 3.416549805340735*^9}, {3.416549860130493*^9, 
   3.416549926747891*^9}, {3.41655000248415*^9, 3.41655001094872*^9}, {
   3.416550097857018*^9, 3.416550111309168*^9}, {3.41655724680367*^9, 
   3.416557292801172*^9}, {3.416557490511381*^9, 3.416557506205907*^9}, {
   3.41655773385179*^9, 3.416557742518362*^9}, {3.416559265226147*^9, 
   3.416559266464175*^9}, {3.416647234311404*^9, 3.416647236859202*^9}, {
   3.416647293391703*^9, 3.416647300257344*^9}, {3.416647367215551*^9, 
   3.416647373409747*^9}, {3.422092081955633*^9, 3.42209209282063*^9}, {
   3.422092130997938*^9, 3.422092176710025*^9}, {3.422092420401489*^9, 
   3.422092584216989*^9}, {3.422092626773941*^9, 3.422092654204989*^9}, {
   3.422092940649434*^9, 3.422092973750673*^9}, 3.422093020022861*^9, {
   3.422093154582986*^9, 3.422093175932726*^9}, {3.422093216089871*^9, 
   3.422093226195519*^9}, {3.422093276506398*^9, 3.422093328864777*^9}, {
   3.422093365249041*^9, 3.422093421099283*^9}, {3.422093467847755*^9, 
   3.422093576921004*^9}, {3.422093619998141*^9, 3.422093620981225*^9}, {
   3.422093664280697*^9, 3.422093665345774*^9}, {3.422263471187633*^9, 
   3.422263495162991*^9}, {3.422263695864656*^9, 3.422263699030241*^9}, {
   3.422263803069658*^9, 3.422263922478056*^9}, {3.422264130207082*^9, 
   3.42226413708146*^9}, {3.422264173147778*^9, 3.422264200863563*^9}, {
   3.42226426514399*^9, 3.422264266120431*^9}, {3.422264422768835*^9, 
   3.422264451008478*^9}, {3.422264552234729*^9, 3.422264568348641*^9}, {
   3.422265525390002*^9, 3.422265540531472*^9}, {3.422265762261359*^9, 
   3.422265765917021*^9}, {3.422266021777035*^9, 3.422266028491106*^9}, {
   3.422335251042448*^9, 3.42233528255884*^9}, {3.422335328751771*^9, 
   3.422335337339104*^9}, {3.422336271014215*^9, 3.422336309357697*^9}, {
   3.422336353743585*^9, 3.422336374195841*^9}, 3.422336416775777*^9, {
   3.422336475495714*^9, 3.42233656369258*^9}, {3.425700079142628*^9, 
   3.425700091745507*^9}, {3.425722857211932*^9, 3.425722941648064*^9}, {
   3.42572358454542*^9, 3.425723713432891*^9}, {3.425723749905504*^9, 
   3.425723806205838*^9}, 3.425725653535913*^9, 3.425789436699319*^9, {
   3.425789474399046*^9, 3.425789484030128*^9}, 3.425789960084166*^9, 
   3.425790109007563*^9, {3.425790302202585*^9, 3.425790302774711*^9}, 
   3.425790649310231*^9, {3.425792808672695*^9, 3.425792822324345*^9}, {
   3.425793243753974*^9, 3.425793276658186*^9}, {3.425793726338795*^9, 
   3.42579372743293*^9}, {3.425793786507801*^9, 3.425793787012029*^9}, {
   3.425793931789602*^9, 3.425793932766534*^9}, {3.425794002696649*^9, 
   3.425794005726171*^9}, {3.425960340264875*^9, 3.425960343443947*^9}, {
   3.425965061631466*^9, 3.425965062032904*^9}, {3.436509797906802*^9, 
   3.436509798199875*^9}, 3.436607826390134*^9, {3.436608180503036*^9, 
   3.436608181881652*^9}, {3.436608233225635*^9, 3.436608233885809*^9}, {
   3.436608267963629*^9, 3.436608268168436*^9}, {3.437828122115043*^9, 
   3.437828138032636*^9}, 3.437828179689353*^9, {3.437828978624173*^9, 
   3.437828979164587*^9}, {3.43782906533818*^9, 3.437829092308376*^9}, 
   3.437829216625093*^9, {3.437995426195938*^9, 3.437995447755848*^9}, {
   3.43799576704351*^9, 3.437995817207429*^9}, 3.437995904710293*^9, {
   3.437996102242542*^9, 3.437996170586153*^9}, 3.437996255623235*^9, {
   3.4379962913253*^9, 3.437996300267291*^9}, {3.437996345921738*^9, 
   3.437996360587183*^9}, {3.437996412506939*^9, 3.437996426320588*^9}, {
   3.43799655920569*^9, 3.437996559393116*^9}, {3.437996637886771*^9, 
   3.437996650115291*^9}, {3.437996681589313*^9, 3.437996686633339*^9}, {
   3.437996746656707*^9, 3.437996783477987*^9}, {3.437996817105654*^9, 
   3.437996837053933*^9}, {3.437996960699935*^9, 3.437997028714444*^9}, {
   3.43799737774688*^9, 3.437997455530492*^9}, {3.437998192810949*^9, 
   3.437998203109471*^9}, {3.437998292972282*^9, 3.437998328251303*^9}, 
   3.438683967014131*^9, {3.438684206459222*^9, 3.438684217734751*^9}, {
   3.438684321887066*^9, 3.43868441498221*^9}, {3.438684591011375*^9, 
   3.438684605885137*^9}, {3.438684672227231*^9, 3.438684889723213*^9}, {
   3.438685779988105*^9, 3.438685796941766*^9}, 3.438685829531893*^9, 
   3.475843609718097*^9},
 Magnification->1.25],

Cell[CellGroupData[{

Cell[BoxData["\<\"EOM:\"\>"], "Print",
 CellChangeTimes->{
  3.437996259295302*^9, 3.437996300920353*^9, 3.437996361862915*^9, 
   3.43799642716328*^9, {3.437996651326085*^9, 3.437996687570084*^9}, 
   3.437996759326073*^9, 3.437996795305928*^9, {3.437996980888983*^9, 
   3.437997007174431*^9}, 3.437997380128001*^9, {3.437997417835917*^9, 
   3.437997457815655*^9}, 3.437998206820943*^9, 3.437998329250536*^9, 
   3.438418077305848*^9, 3.438684226915703*^9, {3.438684385131931*^9, 
   3.438684415668595*^9}, 3.438684607166923*^9, 3.438684689569142*^9, 
   3.438685768455319*^9, 3.438685798851065*^9, 3.438685830216126*^9, 
   3.442929134495779*^9, 3.475843865983633*^9}],

Cell[BoxData[
 TagBox[
  FormBox[
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Rho]0", 
            RowBox[{"1", ",", "1"}]], " ", 
           SubscriptBox["\[CapitalOmega]", "BP"]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "1"}]], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             SubscriptBox["\[Phi]", "mul"]}]], " ", 
           TemplateBox[{RowBox[{"(", 
               SubscriptBox["\[CapitalOmega]", "C"], ")"}]},
            "Conjugate"]}], "+", 
          RowBox[{
           SubscriptBox["\[Rho]", 
            RowBox[{"2", ",", "1"}]], " ", 
           RowBox[{"(", 
            RowBox[{"-", 
             SubscriptBox["\[Gamma]", "p"]}], ")"}]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SubscriptBox["\[Gamma]", 
            RowBox[{"2", ",", "1"}]], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"2", ",", "1"}]]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[CapitalDelta]", 
            RowBox[{"2", ",", "1"}]], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"2", ",", "1"}]]}]}]},
        {
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
            SubscriptBox["\[Rho]", 
             RowBox[{"3", ",", "2"}]], " ", 
            SubscriptBox["\[CapitalOmega]", "BP"]}]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"2", ",", "1"}]], " ", 
           SubscriptBox["\[CapitalOmega]", "C"], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", "mul"]}]]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Rho]0", 
            RowBox[{"4", ",", "1"}]], " ", 
           SubscriptBox["\[CapitalOmega]", "EP"]}], "-", 
          RowBox[{"2", " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "1"}]], " ", 
           SubscriptBox["\[Gamma]", "p"]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SubscriptBox["\[Gamma]", "3"], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "1"}]]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[CapitalDelta]", 
            RowBox[{"2", ",", "1"}]], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "1"}]]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[CapitalDelta]", 
            RowBox[{"3", ",", "2"}]], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "1"}]]}]}]},
        {
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "1"}]], " ", 
           TemplateBox[{RowBox[{"(", 
               SubscriptBox["\[CapitalOmega]", "BP"], ")"}]},
            "Conjugate"]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"4", ",", "2"}]], " ", 
           SubscriptBox["\[CapitalOmega]", "EP"]}], "-", 
          RowBox[{
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "2"}]], " ", 
           SubscriptBox["\[Gamma]", "p"]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SubscriptBox["\[Gamma]", "3"], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "2"}]]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SubscriptBox["\[Gamma]", 
            RowBox[{"2", ",", "1"}]], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "2"}]]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[CapitalDelta]", 
            RowBox[{"3", ",", "2"}]], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "2"}]]}]}]},
        {
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"2", ",", "4"}]], " ", 
           SubscriptBox["\[CapitalOmega]", "C"], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", "mul"]}]]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Rho]0", 
            RowBox[{"4", ",", "4"}]], " ", 
           SubscriptBox["\[CapitalOmega]", "EP"]}], "-", 
          RowBox[{
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "4"}]], " ", 
           SubscriptBox["\[Gamma]", "p"]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SubscriptBox["\[Gamma]", "3"], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "4"}]]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[CapitalDelta]", 
            RowBox[{"2", ",", "1"}]], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "4"}]]}]}]},
        {
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Rho]0", 
            RowBox[{"4", ",", "1"}]], " ", 
           TemplateBox[{RowBox[{"(", 
               SubscriptBox["\[CapitalOmega]", "BP"], ")"}]},
            "Conjugate"]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"4", ",", "3"}]], " ", 
           SubscriptBox["\[CapitalOmega]", "C"], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Phi]", "mul"]}]]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"3", ",", "2"}]], " ", 
           TemplateBox[{RowBox[{"(", 
               SubscriptBox["\[CapitalOmega]", "EP"], ")"}]},
            "Conjugate"]}], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SubscriptBox["\[Gamma]", 
            RowBox[{"2", ",", "1"}]], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"4", ",", "2"}]]}], "-", 
          RowBox[{
           SubscriptBox["\[Gamma]", 
            RowBox[{"4", ",", "2"}]], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"4", ",", "2"}]]}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[CapitalDelta]", 
            RowBox[{"2", ",", "1"}]], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"4", ",", "2"}]]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["\[CapitalDelta]", 
            RowBox[{"3", ",", "2"}]], " ", 
           SubscriptBox["\[Rho]", 
            RowBox[{"4", ",", "2"}]]}]}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{
  3.437996259295302*^9, 3.437996300920353*^9, 3.437996361862915*^9, 
   3.43799642716328*^9, {3.437996651326085*^9, 3.437996687570084*^9}, 
   3.437996759326073*^9, 3.437996795305928*^9, {3.437996980888983*^9, 
   3.437997007174431*^9}, 3.437997380128001*^9, {3.437997417835917*^9, 
   3.437997457815655*^9}, 3.437998206820943*^9, 3.437998329250536*^9, 
   3.438418077305848*^9, 3.438684226915703*^9, {3.438684385131931*^9, 
   3.438684415668595*^9}, 3.438684607166923*^9, 3.438684689569142*^9, 
   3.438685768455319*^9, 3.438685798851065*^9, 3.438685830216126*^9, 
   3.442929134495779*^9, 3.475843866213624*^9}],

Cell[BoxData[
 TagBox[
  FormBox[
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         RowBox[{
          FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["alpha", "2"], " ", "L", " ", "rho011", " ", 
             SubscriptBox["\[Gamma]", 
              RowBox[{"3", ",", "4"}]], " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"2", ",", "1"}]]}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"2", ",", "1"}]], " ", 
             SubscriptBox["\[Gamma]", 
              RowBox[{"c", ",", "ol"}]]}], "+", 
            RowBox[{
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "1"}]], " ", 
             TemplateBox[{RowBox[{"(", 
                 RowBox[{
                   RowBox[{"L", " ", 
                    SubscriptBox["\[Gamma]", 
                    RowBox[{"3", ",", "4"}]], " ", 
                    SubscriptBox["\[Rho]", 
                    RowBox[{"3", ",", "2"}]]}], "+", 
                   SubscriptBox["\[CapitalOmega]", 
                    RowBox[{"3", ",", "2"}]]}], ")"}]},
              "Conjugate"]}], "+", 
            RowBox[{"rho011", " ", 
             SubscriptBox["\[CapitalOmega]", 
              RowBox[{"2", ",", "1"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Gamma]", 
              RowBox[{"2", ",", "1"}]], " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"2", ",", "1"}]]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["\[CapitalDelta]", 
              RowBox[{"2", ",", "1"}]], " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"2", ",", "1"}]]}]}], ")"}]}]},
        {
         RowBox[{
          FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "1"}]], " ", 
             SubscriptBox["\[Gamma]", 
              RowBox[{"3", ",", "all"}]]}], "-", 
            RowBox[{
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "2"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["alpha", "2"], " ", "L", " ", 
                SubscriptBox["\[Gamma]", 
                 RowBox[{"3", ",", "4"}]], " ", 
                SubscriptBox["\[Rho]", 
                 RowBox[{"2", ",", "1"}]]}], "+", 
               SubscriptBox["\[CapitalOmega]", 
                RowBox[{"2", ",", "1"}]]}], ")"}]}], "+", 
            RowBox[{"4", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "1"}]], " ", 
             SubscriptBox["\[Gamma]", 
              RowBox[{"c", ",", "ol"}]]}], "+", 
            RowBox[{"rho041", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"L", " ", 
                SubscriptBox["\[Gamma]", 
                 RowBox[{"3", ",", "4"}]], " ", 
                SubscriptBox["\[Rho]", 
                 RowBox[{"3", ",", "4"}]]}], "+", 
               SubscriptBox["\[CapitalOmega]", 
                RowBox[{"3", ",", "4"}]]}], ")"}]}], "+", 
            RowBox[{
             SubscriptBox["\[Rho]", 
              RowBox[{"2", ",", "1"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"L", " ", 
                SubscriptBox["\[Gamma]", 
                 RowBox[{"3", ",", "4"}]], " ", 
                SubscriptBox["\[Rho]", 
                 RowBox[{"3", ",", "2"}]]}], "+", 
               SubscriptBox["\[CapitalOmega]", 
                RowBox[{"3", ",", "2"}]]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["\[CapitalDelta]", 
              RowBox[{"2", ",", "1"}]], " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "1"}]]}]}], ")"}]}]},
        {
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["\[Rho]", 
               RowBox[{"3", ",", "2"}]], " ", 
              SubscriptBox["\[Gamma]", 
               RowBox[{"3", ",", "all"}]]}]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "1"}]], " ", 
             TemplateBox[{RowBox[{"(", 
                 RowBox[{
                   RowBox[{"L", " ", 
                    SubscriptBox["\[Gamma]", 
                    RowBox[{"3", ",", "4"}]], " ", 
                    SubscriptBox["\[Rho]", 
                    RowBox[{"2", ",", "1"}]], " ", 
                    SuperscriptBox["alpha", "2"]}], "+", 
                   SubscriptBox["\[CapitalOmega]", 
                    RowBox[{"2", ",", "1"}]]}], ")"}]},
              "Conjugate"]}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "2"}]], " ", 
             SubscriptBox["\[Gamma]", 
              RowBox[{"c", ",", "ol"}]]}], "+", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"4", ",", "2"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"L", " ", 
                SubscriptBox["\[Gamma]", 
                 RowBox[{"3", ",", "4"}]], " ", 
                SubscriptBox["\[Rho]", 
                 RowBox[{"3", ",", "4"}]]}], "+", 
               SubscriptBox["\[CapitalOmega]", 
                RowBox[{"3", ",", "4"}]]}], ")"}]}], "-", 
            RowBox[{
             SubscriptBox["\[Gamma]", 
              RowBox[{"2", ",", "1"}]], " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "2"}]]}]}], ")"}]}]},
        {
         RowBox[{
          FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "4"}]], " ", 
             SubscriptBox["\[Gamma]", 
              RowBox[{"3", ",", "all"}]]}], "+", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "4"}]], " ", 
             SubscriptBox["\[Gamma]", 
              RowBox[{"c", ",", "ol"}]]}], "+", 
            RowBox[{
             TemplateBox[{RowBox[{"(", 
                 SubscriptBox["\[Rho]", 
                  RowBox[{"4", ",", "2"}]], ")"}]},
              "Conjugate"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"L", " ", 
                SubscriptBox["\[Gamma]", 
                 RowBox[{"3", ",", "4"}]], " ", 
                SubscriptBox["\[Rho]", 
                 RowBox[{"3", ",", "2"}]]}], "+", 
               SubscriptBox["\[CapitalOmega]", 
                RowBox[{"3", ",", "2"}]]}], ")"}]}], "+", 
            RowBox[{"L", " ", "rho044", " ", 
             SubscriptBox["\[Gamma]", 
              RowBox[{"3", ",", "4"}]], " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "4"}]]}], "+", 
            RowBox[{"rho044", " ", 
             SubscriptBox["\[CapitalOmega]", 
              RowBox[{"3", ",", "4"}]]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["\[CapitalDelta]", 
              RowBox[{"2", ",", "1"}]], " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "4"}]]}]}], ")"}]}]},
        {
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"rho041", " ", 
             TemplateBox[{RowBox[{"(", 
                 RowBox[{
                   RowBox[{"L", " ", 
                    SubscriptBox["\[Gamma]", 
                    RowBox[{"3", ",", "4"}]], " ", 
                    SubscriptBox["\[Rho]", 
                    RowBox[{"2", ",", "1"}]], " ", 
                    SuperscriptBox["alpha", "2"]}], "+", 
                   SubscriptBox["\[CapitalOmega]", 
                    RowBox[{"2", ",", "1"}]]}], ")"}]},
              "Conjugate"]}], "-", 
            RowBox[{
             SubscriptBox["\[Rho]", 
              RowBox[{"3", ",", "2"}]], " ", 
             TemplateBox[{RowBox[{"(", 
                 RowBox[{
                   RowBox[{"L", " ", 
                    SubscriptBox["\[Gamma]", 
                    RowBox[{"3", ",", "4"}]], " ", 
                    SubscriptBox["\[Rho]", 
                    RowBox[{"3", ",", "4"}]]}], "+", 
                   SubscriptBox["\[CapitalOmega]", 
                    RowBox[{"3", ",", "4"}]]}], ")"}]},
              "Conjugate"]}], "+", 
            RowBox[{
             TemplateBox[{RowBox[{"(", 
                 SubscriptBox["\[Rho]", 
                  RowBox[{"3", ",", "4"}]], ")"}]},
              "Conjugate"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"L", " ", 
                SubscriptBox["\[Gamma]", 
                 RowBox[{"3", ",", "4"}]], " ", 
                SubscriptBox["\[Rho]", 
                 RowBox[{"3", ",", "2"}]]}], "+", 
               SubscriptBox["\[CapitalOmega]", 
                RowBox[{"3", ",", "2"}]]}], ")"}]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
             SubscriptBox["\[Gamma]", 
              RowBox[{"2", ",", "1"}]], " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"4", ",", "2"}]]}], "-", 
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             SubscriptBox["\[Gamma]", 
              RowBox[{"4", ",", "2"}]], " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"4", ",", "2"}]]}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["\[CapitalDelta]", 
              RowBox[{"2", ",", "1"}]], " ", 
             SubscriptBox["\[Rho]", 
              RowBox[{"4", ",", "2"}]]}]}], ")"}]}]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "Print",
 CellChangeTimes->{
  3.437996259295302*^9, 3.437996300920353*^9, 3.437996361862915*^9, 
   3.43799642716328*^9, {3.437996651326085*^9, 3.437996687570084*^9}, 
   3.437996759326073*^9, 3.437996795305928*^9, {3.437996980888983*^9, 
   3.437997007174431*^9}, 3.437997380128001*^9, {3.437997417835917*^9, 
   3.437997457815655*^9}, 3.437998206820943*^9, 3.437998329250536*^9, 
   3.438418077305848*^9, 3.438684226915703*^9, {3.438684385131931*^9, 
   3.438684415668595*^9}, 3.438684607166923*^9, 3.438684689569142*^9, 
   3.438685768455319*^9, 3.438685798851065*^9, 3.438685830216126*^9, 
   3.442929134495779*^9, 3.475843866680827*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sysvecR", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ToString", "[", 
       RowBox[{"CForm", "[", "#1", "]"}], "]"}], "&"}], ",", 
     OverscriptBox["\[Rho]", "^"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sysvecR", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"StringReplace", "[", 
       RowBox[{"#1", ",", 
        RowBox[{
         RowBox[{"Shortest", "[", 
          RowBox[{
          "\"\<Subscript(\>\"", "~~", "x__", "~~", "\"\<,\>\"", "~~", "y__", 
           "~~", "\"\<,\>\"", "~~", "z__", "~~", "\"\<)\>\""}], "]"}], 
         "\[Rule]", 
         RowBox[{"x", "~~", "y", "~~", "z"}]}]}], "]"}], "&"}], ",", 
     "sysvecR"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"sysvecR", "=", 
  RowBox[{"Delete", "[", 
   RowBox[{"sysvecR", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "1", "}"}], ",", 
      RowBox[{"{", "2", "}"}], ",", 
      RowBox[{"{", "4", "}"}], ",", 
      RowBox[{"{", "5", "}"}], ",", 
      RowBox[{"{", "10", "}"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sysvecO", "=", 
   RowBox[{"{", 
    RowBox[{"O34", ",", "O21", ",", "O32"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dimR", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dimO", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"sysvecO", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ToString", "[", "#1", "]"}], "&"}], ",", "sysvecO"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ConvertToCString", "[", "str_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp", ",", "i"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"tmp", "=", "str"}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"Expand", "[", "tmp", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"ToString", "[", 
        RowBox[{"CForm", "[", "tmp", "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"StringReplace", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{
          RowBox[{"Shortest", "[", "\"\<Complex(0,1)\>\"", "]"}], "\[Rule]", 
          "\"\<I\>\""}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"StringReplace", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{
          RowBox[{"Shortest", "[", 
           RowBox[{"\"\<Complex(0,\>\"", "~~", "y__", "~~", "\"\<)\>\""}], 
           "]"}], "\[Rule]", 
          RowBox[{"y", "~~", "\"\<*I\>\""}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"StringReplace", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{
          RowBox[{"Shortest", "[", 
           RowBox[{"\"\<Conjugate(\>\"", "~~", "x__", "~~", "\"\<)\>\""}], 
           "]"}], "\[Rule]", 
          RowBox[{"\"\<conj(\>\"", "~~", "x", "~~", "\"\<)\>\""}]}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"StringReplace", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{"\"\<\[Gamma]\>\"", "\[Rule]", "\"\<gam\>\""}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"StringReplace", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{
          RowBox[{"Shortest", "[", 
           RowBox[{"\"\<Power(\>\"", "~~", "x__", "~~", "\"\<,2)\>\""}], 
           "]"}], "\[Rule]", 
          RowBox[{"x", "~~", "\"\<*\>\"", "~~", "x"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"StringReplace", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{"\"\<\[CapitalOmega]\>\"", "\[Rule]", "\"\<O\>\""}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"StringReplace", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{"\"\<\[CapitalDelta]\>\"", "\[Rule]", "\"\<Delta\>\""}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"StringReplace", "[", 
        RowBox[{"tmp", ",", 
         RowBox[{
          RowBox[{"Shortest", "[", 
           RowBox[{
           "\"\<Subscript(\>\"", "~~", "x__", "~~", "\"\<,\>\"", "~~", "y__", 
            "~~", "\"\<,\>\"", "~~", "z__", "~~", "\"\<)\>\""}], "]"}], 
          "\[Rule]", 
          RowBox[{"x", "~~", "y", "~~", "z"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"j", "=", "1"}], ",", 
        RowBox[{"j", "\[LessEqual]", "dimR"}], ",", 
        RowBox[{"j", "++"}], ",", 
        RowBox[{"tmp", "=", 
         RowBox[{"StringReplace", "[", 
          RowBox[{"tmp", ",", 
           RowBox[{
            RowBox[{"sysvecR", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "\[Rule]", 
            RowBox[{"\"\<R[\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"j", "-", "1"}], "]"}], "<>", "\"\<]\>\""}]}]}], " ", 
          "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"j", "=", "1"}], ",", 
        RowBox[{"j", "\[LessEqual]", "dimO"}], ",", 
        RowBox[{"j", "++"}], ",", 
        RowBox[{"tmp", "=", 
         RowBox[{"StringReplace", "[", 
          RowBox[{"tmp", ",", 
           RowBox[{
            RowBox[{"sysvecO", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "\[Rule]", 
            RowBox[{"\"\<O[\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"j", "-", "1"}], "]"}], "<>", "\"\<]\>\""}]}]}], " ", 
          "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", "tmp"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"strm", "=", 
   RowBox[{"OpenWrite", "[", 
    RowBox[{"path", "<>", "\"\<c-eom.dat\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"strm", ",", 
    RowBox[{"FormatType", "->", "OutputForm"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"strm", ",", 
    RowBox[{"PageWidth", "\[Rule]", "Infinity"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<EOM in C-form:\>\"", "]"}], ";"}], "\n", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"i", "=", "1"}], ",", 
   RowBox[{"i", "\[LessEqual]", "dimR"}], ",", 
   RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Write", "[", 
     RowBox[{"strm", ",", 
      RowBox[{"\"\<\\t// d/dt\>\"", "<>", 
       RowBox[{"sysvecR", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"Write", "[", 
     RowBox[{"strm", ",", 
      RowBox[{"\"\<\\tdRdt[\>\"", "<>", 
       RowBox[{"ToString", "[", 
        RowBox[{"i", "-", "1"}], "]"}], "<>", "\"\<] = \>\"", "<>", 
       RowBox[{"ConvertToCString", "[", 
        RowBox[{"eom", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
         "]"}], "<>", "\"\<;\\n\\t\>\""}]}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Print", "[", "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"Print", "[", 
     RowBox[{"\"\<dRdt[\>\"", "<>", 
      RowBox[{"ToString", "[", 
       RowBox[{"i", "-", "1"}], "]"}], "<>", "\"\<] = \>\"", "<>", 
      RowBox[{"ConvertToCString", "[", 
       RowBox[{"eom", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
       "]"}], "<>", "\"\<;\\n\>\""}], "]"}], ";"}]}], "\[IndentingNewLine]", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Close", "[", "strm", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.3947959744209347`*^9, 3.394796019607855*^9}, {
   3.394796050435442*^9, 3.394796100157537*^9}, {3.394796179878022*^9, 
   3.394796240333954*^9}, {3.3947962964758368`*^9, 3.394796326498702*^9}, {
   3.394796370125268*^9, 3.394796371079192*^9}, {3.397881187429283*^9, 
   3.397881277691527*^9}, {3.397881397908836*^9, 3.397881685723113*^9}, {
   3.397881716782628*^9, 3.39788172514751*^9}, {3.397900472046429*^9, 
   3.397900511683171*^9}, {3.397900585486332*^9, 3.397900593322294*^9}, {
   3.398076437596349*^9, 3.398076483511471*^9}, {3.416548261386902*^9, 
   3.416548573551276*^9}, {3.416548642724583*^9, 3.416548754863226*^9}, {
   3.416548854886367*^9, 3.416549009004696*^9}, {3.416549047093645*^9, 
   3.416549052488327*^9}, {3.416549112815584*^9, 3.416549115833775*^9}, {
   3.416549147994573*^9, 3.416549238604943*^9}, {3.416549596109817*^9, 
   3.416549656511954*^9}, {3.416549716238039*^9, 3.416549736363206*^9}, {
   3.416549767577893*^9, 3.416549805340735*^9}, {3.416549860130493*^9, 
   3.416549926747891*^9}, {3.41655000248415*^9, 3.41655001094872*^9}, {
   3.416550097857018*^9, 3.416550111309168*^9}, {3.41655724680367*^9, 
   3.416557292801172*^9}, {3.416557490511381*^9, 3.416557506205907*^9}, {
   3.41655773385179*^9, 3.416557742518362*^9}, {3.416559265226147*^9, 
   3.416559266464175*^9}, {3.416647234311404*^9, 3.416647236859202*^9}, {
   3.416647293391703*^9, 3.416647300257344*^9}, {3.416647367215551*^9, 
   3.416647373409747*^9}, {3.422092081955633*^9, 3.42209209282063*^9}, {
   3.422092130997938*^9, 3.422092176710025*^9}, {3.422092420401489*^9, 
   3.422092584216989*^9}, {3.422092626773941*^9, 3.422092654204989*^9}, {
   3.422092940649434*^9, 3.422092973750673*^9}, 3.422093020022861*^9, {
   3.422093154582986*^9, 3.422093175932726*^9}, {3.422093216089871*^9, 
   3.422093226195519*^9}, {3.422093276506398*^9, 3.422093328864777*^9}, {
   3.422093365249041*^9, 3.422093421099283*^9}, {3.422093467847755*^9, 
   3.422093576921004*^9}, {3.422093619998141*^9, 3.422093620981225*^9}, {
   3.422093664280697*^9, 3.422093665345774*^9}, {3.422263471187633*^9, 
   3.422263495162991*^9}, {3.422263695864656*^9, 3.422263699030241*^9}, {
   3.422263803069658*^9, 3.422263922478056*^9}, {3.422264130207082*^9, 
   3.42226413708146*^9}, {3.422264173147778*^9, 3.422264200863563*^9}, {
   3.42226426514399*^9, 3.422264266120431*^9}, {3.422264422768835*^9, 
   3.422264451008478*^9}, {3.422264552234729*^9, 3.422264568348641*^9}, {
   3.422265525390002*^9, 3.422265540531472*^9}, {3.422265762261359*^9, 
   3.422265765917021*^9}, {3.422266021777035*^9, 3.422266028491106*^9}, {
   3.422335251042448*^9, 3.42233528255884*^9}, {3.422335328751771*^9, 
   3.422335337339104*^9}, {3.422336271014215*^9, 3.422336309357697*^9}, {
   3.422336353743585*^9, 3.422336374195841*^9}, 3.422336416775777*^9, {
   3.422336475495714*^9, 3.42233656369258*^9}, {3.425700079142628*^9, 
   3.425700091745507*^9}, {3.425722857211932*^9, 3.425722941648064*^9}, {
   3.42572358454542*^9, 3.425723713432891*^9}, {3.425723749905504*^9, 
   3.425723806205838*^9}, 3.425725653535913*^9, 3.425789436699319*^9, {
   3.425789474399046*^9, 3.425789484030128*^9}, 3.425789960084166*^9, 
   3.425790109007563*^9, {3.425790302202585*^9, 3.425790302774711*^9}, 
   3.425790649310231*^9, {3.425792808672695*^9, 3.425792822324345*^9}, {
   3.425793243753974*^9, 3.425793276658186*^9}, {3.425793726338795*^9, 
   3.42579372743293*^9}, {3.425793786507801*^9, 3.425793787012029*^9}, {
   3.425793931789602*^9, 3.425793932766534*^9}, {3.425794002696649*^9, 
   3.425794005726171*^9}, {3.425960340264875*^9, 3.425960343443947*^9}, {
   3.425965061631466*^9, 3.425965062032904*^9}, {3.436509797906802*^9, 
   3.436509798199875*^9}, 3.436607826390134*^9, {3.436608180503036*^9, 
   3.436608181881652*^9}, {3.436608233225635*^9, 3.436608233885809*^9}, {
   3.436608267963629*^9, 3.436608268168436*^9}, {3.437828122115043*^9, 
   3.437828138032636*^9}, 3.437828179689353*^9, {3.437828978624173*^9, 
   3.437828979164587*^9}, {3.43782906533818*^9, 3.437829092308376*^9}, 
   3.437829216625093*^9, {3.437995426195938*^9, 3.437995447755848*^9}, {
   3.43799576704351*^9, 3.437995817207429*^9}, 3.437995904710293*^9, {
   3.437996102242542*^9, 3.437996170586153*^9}, 3.437996255623235*^9, {
   3.437996464494686*^9, 3.437996479695472*^9}, {3.437997090730201*^9, 
   3.437997140745755*^9}, {3.437997211570944*^9, 3.437997211791489*^9}, {
   3.437997668002144*^9, 3.437997699905542*^9}, {3.438685902331127*^9, 
   3.438686000238937*^9}},
 Magnification->1.25],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\[Rho]21\"\>", ",", "\<\"\[Rho]31\"\>", 
   ",", "\<\"\[Rho]32\"\>", ",", "\<\"\[Rho]34\"\>", 
   ",", "\<\"\[Rho]42\"\>"}], "}"}]], "Output",
 CellChangeTimes->{
  3.437995772900209*^9, 3.437995818357706*^9, 3.437995906309898*^9, 
   3.437996104032968*^9, 3.437996172252544*^9, 3.437996370726369*^9, 
   3.437996435261663*^9, 3.437996480479194*^9, {3.437997096580874*^9, 
   3.437997141077745*^9}, 3.4379972128338*^9, 3.437997469163131*^9, {
   3.437997684215556*^9, 3.437997700927504*^9}, 3.43799822015236*^9, 
   3.437998338112921*^9, 3.438418077563073*^9, 3.438684240481438*^9, 
   3.438684446510814*^9, {3.438685817847379*^9, 3.438685833742237*^9}, {
   3.438685986017886*^9, 3.438686002711374*^9}, 3.442929134783843*^9, 
   3.475843876208763*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"O34\"\>", ",", "\<\"O21\"\>", ",", "\<\"O32\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.437995772900209*^9, 3.437995818357706*^9, 3.437995906309898*^9, 
   3.437996104032968*^9, 3.437996172252544*^9, 3.437996370726369*^9, 
   3.437996435261663*^9, 3.437996480479194*^9, {3.437997096580874*^9, 
   3.437997141077745*^9}, 3.4379972128338*^9, 3.437997469163131*^9, {
   3.437997684215556*^9, 3.437997700927504*^9}, 3.43799822015236*^9, 
   3.437998338112921*^9, 3.438418077563073*^9, 3.438684240481438*^9, 
   3.438684446510814*^9, {3.438685817847379*^9, 3.438685833742237*^9}, {
   3.438685986017886*^9, 3.438686002711374*^9}, 3.442929134783843*^9, 
   3.475843876330056*^9}],

Cell[CellGroupData[{

Cell[BoxData["\<\"EOM in C-form:\"\>"], "Print",
 CellChangeTimes->{3.438686002809029*^9, 3.442929134849662*^9, 
  3.475843876443231*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.438686002809029*^9, 3.442929134849662*^9, 
  3.475843876481418*^9}],

Cell[BoxData["\<\"dRdt[0] = -(gam21*R[0])/2. + \
0.5*I*alpha*alpha*L*rho011*gam34*R[0] - gamcol*R[0] + I*Delta21*R[0] + \
0.5*I*conj(L*gam34*R[2] + O[2])*R[1] + 0.5*I*rho011*O[1];\\n\"\>"], "Print",
 CellChangeTimes->{3.438686002809029*^9, 3.442929134849662*^9, 
  3.475843876593491*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.438686002809029*^9, 3.442929134849662*^9, 
  3.475843876628897*^9}],

Cell[BoxData["\<\"dRdt[1] = -(gam3all*R[1])/2. - 2*gamcol*R[1] + \
I*Delta21*R[1] + 0.5*I*L*gam34*R[0]*R[2] - \
0.5*I*alpha*alpha*L*gam34*R[0]*R[2] + 0.5*I*L*rho041*gam34*R[3] - \
0.5*I*R[2]*O[1] + 0.5*I*R[0]*O[2] + 0.5*I*rho041*O[0];\\n\"\>"], "Print",
 CellChangeTimes->{3.438686002809029*^9, 3.442929134849662*^9, 
  3.475843876663537*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.438686002809029*^9, 3.442929134849662*^9, 
  3.475843876719871*^9}],

Cell[BoxData["\<\"dRdt[2] = -0.5*I*conj(alpha*alpha*L*gam34*R[0] + O[1])*R[1] \
- (gam21*R[2])/2. - (gam3all*R[2])/2. - gamcol*R[2] + 0.5*I*L*gam34*R[3]*R[4] \
+ 0.5*I*R[4]*O[0];\\n\"\>"], "Print",
 CellChangeTimes->{3.438686002809029*^9, 3.442929134849662*^9, 
  3.475843876760605*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.438686002809029*^9, 3.442929134849662*^9, 
  3.475843876822107*^9}],

Cell[BoxData["\<\"dRdt[3] = 0.5*I*L*conj(R[4])*gam34*R[2] + \
0.5*I*L*rho044*gam34*R[3] - (gam3all*R[3])/2. - gamcol*R[3] + I*Delta21*R[3] \
+ 0.5*I*conj(R[4])*O[2] + 0.5*I*rho044*O[0];\\n\"\>"], "Print",
 CellChangeTimes->{3.438686002809029*^9, 3.442929134849662*^9, 
  3.475843876859032*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{3.438686002809029*^9, 3.442929134849662*^9, 
  3.475843876911464*^9}],

Cell[BoxData["\<\"dRdt[4] = -0.5*I*rho041*conj(alpha*alpha*L*gam34*R[0] + \
O[1]) + 0.5*I*conj(L*gam34*R[3] + O[0])*R[2] - 0.5*I*L*conj(R[3])*gam34*R[2] \
- (gam21*R[4])/2. - gam42*R[4] - I*Delta21*R[4] - 0.5*I*conj(R[3])*O[2];\\n\"\
\>"], "Print",
 CellChangeTimes->{3.438686002809029*^9, 3.442929134849662*^9, 
  3.475843876948039*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{1230, 817},
WindowMargins->{{Automatic, 16}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "theo", 
   "fleischr", "Mathematica Notebooks"}, "Double-Lambda System.nb.ps", 
  CharacterEncoding -> "iso8859-1"],
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{54, 54}, {72, 72}}},
Magnification->1.25,
FrontEndVersion->"7.0 for Linux x86 (32-bit) (February 25, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 170, 3, 89, "Section"],
Cell[CellGroupData[{
Cell[762, 29, 185, 3, 47, "Subsection"],
Cell[950, 34, 668, 13, 61, "Text"],
Cell[CellGroupData[{
Cell[1643, 51, 123, 5, 57, "Subsubsection"],
Cell[CellGroupData[{
Cell[1791, 60, 30942, 828, 1574, "Input"],
Cell[CellGroupData[{
Cell[32758, 892, 578, 9, 30, "Print"],
Cell[33339, 903, 8806, 224, 157, "Print"],
Cell[42148, 1129, 584, 9, 30, "Print"],
Cell[42735, 1140, 2681, 71, 105, "Print"],
Cell[45419, 1213, 590, 9, 30, "Print"],
Cell[46012, 1224, 4441, 121, 171, "Print"],
Cell[50456, 1347, 1520, 34, 32, "Print"],
Cell[51979, 1383, 1520, 34, 32, "Print"],
Cell[53502, 1419, 1796, 40, 32, "Print"],
Cell[55301, 1461, 584, 9, 30, "Print"],
Cell[55888, 1472, 9466, 242, 335, "Print"],
Cell[65357, 1716, 3431, 93, 282, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[68861, 1817, 5985, 82, 47, "Subsection"],
Cell[CellGroupData[{
Cell[74871, 1903, 10604, 227, 344, "Input"],
Cell[CellGroupData[{
Cell[85500, 2134, 672, 10, 30, "Print"],
Cell[86175, 2146, 8618, 217, 157, "Print"],
Cell[94796, 2365, 11284, 278, 165, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[106129, 2649, 12179, 265, 868, "Input"],
Cell[118311, 2916, 796, 14, 38, "Output"],
Cell[119110, 2932, 726, 13, 38, "Output"],
Cell[CellGroupData[{
Cell[119861, 2949, 137, 2, 30, "Print"],
Cell[120001, 2953, 123, 2, 30, "Print"],
Cell[120127, 2957, 287, 4, 81, "Print"],
Cell[120417, 2963, 123, 2, 30, "Print"],
Cell[120543, 2967, 342, 5, 106, "Print"],
Cell[120888, 2974, 123, 2, 30, "Print"],
Cell[121014, 2978, 286, 4, 81, "Print"],
Cell[121303, 2984, 123, 2, 30, "Print"],
Cell[121429, 2988, 293, 4, 81, "Print"],
Cell[121725, 2994, 123, 2, 30, "Print"],
Cell[121851, 2998, 337, 5, 81, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
